# !!!!!!!   DO NOT EDIT THIS FILE   !!!!!!!
# This file is machine-generated by lib/unicore/mktables from the Unicode
# database, Version 5.2.0.  Any changes made here will be lost!


# !!!!!!!   INTERNAL PERL USE ONLY   !!!!!!!
# This file is for internal use by the Perl program only.  The format and even
# the name or existence of this file are subject to change without notice.
# Don't use it directly.


# This file is for the use of utf8_heavy.pl

# Maps property names in loose standard form to its standard name
%utf8::loose_property_name_of = (
    'age' => 'age',
    'ahex' => 'ahex',
    'alpha' => 'alpha',
    'alphabetic' => 'alpha',
    'asciihexdigit' => 'ahex',
    'bc' => 'bc',
    'bidic' => 'bidic',
    'bidiclass' => 'bc',
    'bidicontrol' => 'bidic',
    'bidim' => 'bidim',
    'bidimirrored' => 'bidim',
    'blk' => 'blk',
    'block' => 'blk',
    'canonicalcombiningclass' => 'ccc',
    'cased' => 'cased',
    'caseignorable' => 'ci',
    'category' => 'gc',
    'ccc' => 'ccc',
    'ce' => 'ce',
    'changeswhencasefolded' => 'cwcf',
    'changeswhencasemapped' => 'cwcm',
    'changeswhenlowercased' => 'cwl',
    'changeswhennfkccasefolded' => 'cwkcf',
    'changeswhentitlecased' => 'cwt',
    'changeswhenuppercased' => 'cwu',
    'ci' => 'ci',
    'compex' => 'compex',
    'compositionexclusion' => 'ce',
    'cwcf' => 'cwcf',
    'cwcm' => 'cwcm',
    'cwkcf' => 'cwkcf',
    'cwl' => 'cwl',
    'cwt' => 'cwt',
    'cwu' => 'cwu',
    'dash' => 'dash',
    'decompositiontype' => 'dt',
    'defaultignorablecodepoint' => 'di',
    'dep' => 'dep',
    'deprecated' => 'dep',
    'di' => 'di',
    'dia' => 'dia',
    'diacritic' => 'dia',
    'dt' => 'dt',
    'ea' => 'ea',
    'eastasianwidth' => 'ea',
    'ext' => 'ext',
    'extender' => 'ext',
    'fullcompositionexclusion' => 'compex',
    'gc' => 'gc',
    'gcb' => 'gcb',
    'generalcategory' => 'gc',
    'graphemebase' => 'grbase',
    'graphemeclusterbreak' => 'gcb',
    'graphemeextend' => 'grext',
    'grbase' => 'grbase',
    'grext' => 'grext',
    'hangulsyllabletype' => 'hst',
    'hex' => 'hex',
    'hexdigit' => 'hex',
    'hst' => 'hst',
    'hyphen' => 'hyphen',
    'idc' => 'idc',
    'idcontinue' => 'idc',
    'ideo' => 'ideo',
    'ideographic' => 'ideo',
    'ids' => 'ids',
    'idsb' => 'idsb',
    'idsbinaryoperator' => 'idsb',
    'idst' => 'idst',
    'idstart' => 'ids',
    'idstrinaryoperator' => 'idst',
    'in' => 'in',
    'isage' => 'age',
    'isahex' => 'ahex',
    'isalpha' => 'alpha',
    'isalphabetic' => 'alpha',
    'isasciihexdigit' => 'ahex',
    'isbc' => 'bc',
    'isbidic' => 'bidic',
    'isbidiclass' => 'bc',
    'isbidicontrol' => 'bidic',
    'isbidim' => 'bidim',
    'isbidimirrored' => 'bidim',
    'isblk' => 'blk',
    'isblock' => 'blk',
    'iscanonicalcombiningclass' => 'ccc',
    'iscased' => 'cased',
    'iscaseignorable' => 'ci',
    'iscategory' => 'gc',
    'isccc' => 'ccc',
    'isce' => 'ce',
    'ischangeswhencasefolded' => 'cwcf',
    'ischangeswhencasemapped' => 'cwcm',
    'ischangeswhenlowercased' => 'cwl',
    'ischangeswhennfkccasefolded' => 'cwkcf',
    'ischangeswhentitlecased' => 'cwt',
    'ischangeswhenuppercased' => 'cwu',
    'isci' => 'ci',
    'iscompex' => 'compex',
    'iscompositionexclusion' => 'ce',
    'iscwcf' => 'cwcf',
    'iscwcm' => 'cwcm',
    'iscwkcf' => 'cwkcf',
    'iscwl' => 'cwl',
    'iscwt' => 'cwt',
    'iscwu' => 'cwu',
    'isdash' => 'dash',
    'isdecompositiontype' => 'dt',
    'isdefaultignorablecodepoint' => 'di',
    'isdep' => 'dep',
    'isdeprecated' => 'dep',
    'isdi' => 'di',
    'isdia' => 'dia',
    'isdiacritic' => 'dia',
    'isdt' => 'dt',
    'isea' => 'ea',
    'iseastasianwidth' => 'ea',
    'isext' => 'ext',
    'isextender' => 'ext',
    'isfullcompositionexclusion' => 'compex',
    'isgc' => 'gc',
    'isgcb' => 'gcb',
    'isgeneralcategory' => 'gc',
    'isgraphemebase' => 'grbase',
    'isgraphemeclusterbreak' => 'gcb',
    'isgraphemeextend' => 'grext',
    'isgrbase' => 'grbase',
    'isgrext' => 'grext',
    'ishangulsyllabletype' => 'hst',
    'ishex' => 'hex',
    'ishexdigit' => 'hex',
    'ishst' => 'hst',
    'ishyphen' => 'hyphen',
    'isidc' => 'idc',
    'isidcontinue' => 'idc',
    'isideo' => 'ideo',
    'isideographic' => 'ideo',
    'isids' => 'ids',
    'isidsb' => 'idsb',
    'isidsbinaryoperator' => 'idsb',
    'isidst' => 'idst',
    'isidstart' => 'ids',
    'isidstrinaryoperator' => 'idst',
    'isjg' => 'jg',
    'isjoinc' => 'joinc',
    'isjoincontrol' => 'joinc',
    'isjoininggroup' => 'jg',
    'isjoiningtype' => 'jt',
    'isjt' => 'jt',
    'islb' => 'lb',
    'islinebreak' => 'lb',
    'isloe' => 'loe',
    'islogicalorderexception' => 'loe',
    'islower' => 'lower',
    'islowercase' => 'lower',
    'ismath' => 'math',
    'isnchar' => 'nchar',
    'isnfcqc' => 'nfcqc',
    'isnfcquickcheck' => 'nfcqc',
    'isnfdqc' => 'nfdqc',
    'isnfdquickcheck' => 'nfdqc',
    'isnfkcqc' => 'nfkcqc',
    'isnfkcquickcheck' => 'nfkcqc',
    'isnfkdqc' => 'nfkdqc',
    'isnfkdquickcheck' => 'nfkdqc',
    'isnoncharactercodepoint' => 'nchar',
    'isnt' => 'nt',
    'isnumerictype' => 'nt',
    'isnumericvalue' => 'nv',
    'isnv' => 'nv',
    'isoalpha' => 'oalpha',
    'isodi' => 'odi',
    'isogrext' => 'ogrext',
    'isoidc' => 'oidc',
    'isoids' => 'oids',
    'isolower' => 'olower',
    'isomath' => 'omath',
    'isotheralphabetic' => 'oalpha',
    'isotherdefaultignorablecodepoint' => 'odi',
    'isothergraphemeextend' => 'ogrext',
    'isotheridcontinue' => 'oidc',
    'isotheridstart' => 'oids',
    'isotherlowercase' => 'olower',
    'isothermath' => 'omath',
    'isotheruppercase' => 'oupper',
    'isoupper' => 'oupper',
    'ispatsyn' => 'patsyn',
    'ispatternsyntax' => 'patsyn',
    'ispatternwhitespace' => 'patws',
    'ispatws' => 'patws',
    'isqmark' => 'qmark',
    'isquotationmark' => 'qmark',
    'isradical' => 'radical',
    'issb' => 'sb',
    'issc' => 'sc',
    'isscript' => 'sc',
    'issd' => 'sd',
    'issentencebreak' => 'sb',
    'issoftdotted' => 'sd',
    'isspace' => 'wspace',
    'issterm' => 'sterm',
    'isterm' => 'term',
    'isterminalpunctuation' => 'term',
    'isuideo' => 'uideo',
    'isunifiedideograph' => 'uideo',
    'isupper' => 'upper',
    'isuppercase' => 'upper',
    'isvariationselector' => 'vs',
    'isvs' => 'vs',
    'iswb' => 'wb',
    'iswhitespace' => 'wspace',
    'iswordbreak' => 'wb',
    'iswspace' => 'wspace',
    'isxidc' => 'xidc',
    'isxidcontinue' => 'xidc',
    'isxids' => 'xids',
    'isxidstart' => 'xids',
    'jg' => 'jg',
    'joinc' => 'joinc',
    'joincontrol' => 'joinc',
    'joininggroup' => 'jg',
    'joiningtype' => 'jt',
    'jt' => 'jt',
    'lb' => 'lb',
    'linebreak' => 'lb',
    'loe' => 'loe',
    'logicalorderexception' => 'loe',
    'lower' => 'lower',
    'lowercase' => 'lower',
    'math' => 'math',
    'nchar' => 'nchar',
    'nfcqc' => 'nfcqc',
    'nfcquickcheck' => 'nfcqc',
    'nfdqc' => 'nfdqc',
    'nfdquickcheck' => 'nfdqc',
    'nfkcqc' => 'nfkcqc',
    'nfkcquickcheck' => 'nfkcqc',
    'nfkdqc' => 'nfkdqc',
    'nfkdquickcheck' => 'nfkdqc',
    'noncharactercodepoint' => 'nchar',
    'nt' => 'nt',
    'numerictype' => 'nt',
    'numericvalue' => 'nv',
    'nv' => 'nv',
    'oalpha' => 'oalpha',
    'odi' => 'odi',
    'ogrext' => 'ogrext',
    'oidc' => 'oidc',
    'oids' => 'oids',
    'olower' => 'olower',
    'omath' => 'omath',
    'otheralphabetic' => 'oalpha',
    'otherdefaultignorablecodepoint' => 'odi',
    'othergraphemeextend' => 'ogrext',
    'otheridcontinue' => 'oidc',
    'otheridstart' => 'oids',
    'otherlowercase' => 'olower',
    'othermath' => 'omath',
    'otheruppercase' => 'oupper',
    'oupper' => 'oupper',
    'patsyn' => 'patsyn',
    'patternsyntax' => 'patsyn',
    'patternwhitespace' => 'patws',
    'patws' => 'patws',
    'perlcanonicalcombiningclass' => 'perlccc',
    'perlccc' => 'perlccc',
    'presentin' => 'in',
    'qmark' => 'qmark',
    'quotationmark' => 'qmark',
    'radical' => 'radical',
    'sb' => 'sb',
    'sc' => 'sc',
    'script' => 'sc',
    'sd' => 'sd',
    'sentencebreak' => 'sb',
    'softdotted' => 'sd',
    'space' => 'wspace',
    'sterm' => 'sterm',
    'term' => 'term',
    'terminalpunctuation' => 'term',
    'uideo' => 'uideo',
    'unifiedideograph' => 'uideo',
    'upper' => 'upper',
    'uppercase' => 'upper',
    'variationselector' => 'vs',
    'vs' => 'vs',
    'wb' => 'wb',
    'whitespace' => 'wspace',
    'wordbreak' => 'wb',
    'wspace' => 'wspace',
    'xidc' => 'xidc',
    'xidcontinue' => 'xidc',
    'xids' => 'xids',
    'xidstart' => 'xids',
);

# Maps property, table to file for those using stricter matching
%utf8::stricter_to_file_of = (
    '_canondcij' => 'SD/Y',
    '_case_ignorable' => 'CI/Y',
    '_combabove' => 'Ccc/A',
    '_x_begin' => 'Perl/_XBegin',
    '_x_extend' => 'Perl/_XExtend',
    '_x_lv_lvt_v' => 'Perl/_XLVLVTV',
    'age=1.1' => 'Age/1_1',
    'age=2' => 'Age/2_0',
    'age=2.0' => 'Age/2_0',
    'age=2.1' => 'Age/2_1',
    'age=3' => 'Age/3_0',
    'age=3.0' => 'Age/3_0',
    'age=3.1' => 'Age/3_1',
    'age=3.2' => 'Age/3_2',
    'age=4' => 'Age/4_0',
    'age=4.0' => 'Age/4_0',
    'age=4.1' => 'Age/4_1',
    'age=5' => 'Age/5_0',
    'age=5.0' => 'Age/5_0',
    'age=5.1' => 'Age/5_1',
    'age=5.2' => 'Age/5_2',
    'ccc=0' => 'Ccc/NR',
    'ccc=1' => 'Ccc/OV',
    'ccc=10' => 'Ccc/10',
    'ccc=103' => 'Ccc/103',
    'ccc=107' => 'Ccc/107',
    'ccc=11' => 'Ccc/11',
    'ccc=118' => 'Ccc/118',
    'ccc=12' => 'Ccc/12',
    'ccc=122' => 'Ccc/122',
    'ccc=129' => 'Ccc/129',
    'ccc=13' => 'Ccc/13',
    'ccc=130' => 'Ccc/130',
    'ccc=132' => 'Ccc/132',
    'ccc=14' => 'Ccc/14',
    'ccc=15' => 'Ccc/15',
    'ccc=16' => 'Ccc/16',
    'ccc=17' => 'Ccc/17',
    'ccc=18' => 'Ccc/18',
    'ccc=19' => 'Ccc/19',
    'ccc=20' => 'Ccc/20',
    'ccc=200' => 'Ccc/ATBL',
    'ccc=202' => 'Ccc/ATB',
    'ccc=21' => 'Ccc/21',
    'ccc=214' => 'Ccc/ATA',
    'ccc=216' => 'Ccc/ATAR',
    'ccc=218' => 'Ccc/BL',
    'ccc=22' => 'Ccc/22',
    'ccc=220' => 'Ccc/B',
    'ccc=222' => 'Ccc/BR',
    'ccc=224' => 'Ccc/L',
    'ccc=226' => 'Ccc/R',
    'ccc=228' => 'Ccc/AL',
    'ccc=23' => 'Ccc/23',
    'ccc=230' => 'Ccc/A',
    'ccc=232' => 'Ccc/AR',
    'ccc=233' => 'Ccc/DB',
    'ccc=234' => 'Ccc/DA',
    'ccc=24' => 'Ccc/24',
    'ccc=240' => 'Ccc/IS',
    'ccc=25' => 'Ccc/25',
    'ccc=26' => 'Ccc/26',
    'ccc=27' => 'Ccc/27',
    'ccc=28' => 'Ccc/28',
    'ccc=29' => 'Ccc/29',
    'ccc=30' => 'Ccc/30',
    'ccc=31' => 'Ccc/31',
    'ccc=32' => 'Ccc/32',
    'ccc=33' => 'Ccc/33',
    'ccc=34' => 'Ccc/34',
    'ccc=35' => 'Ccc/35',
    'ccc=36' => 'Ccc/36',
    'ccc=7' => 'Ccc/NK',
    'ccc=8' => 'Ccc/KV',
    'ccc=84' => 'Ccc/84',
    'ccc=9' => 'Ccc/VR',
    'ccc=91' => 'Ccc/91',
    'in=1.1' => 'Age/1_1',
    'in=2' => 'In/2_0',
    'in=2.0' => 'In/2_0',
    'in=2.1' => 'In/2_1',
    'in=3' => 'In/3_0',
    'in=3.0' => 'In/3_0',
    'in=3.1' => 'In/3_1',
    'in=3.2' => 'In/3_2',
    'in=4' => 'In/4_0',
    'in=4.0' => 'In/4_0',
    'in=4.1' => 'In/4_1',
    'in=5' => 'In/5_0',
    'in=5.0' => 'In/5_0',
    'in=5.1' => 'In/5_1',
    'in=5.2' => 'In/5_2',
    'nv=-1/2' => 'Nv/_1_2',
    'nv=0' => 'Nv/0',
    'nv=1' => 'Nv/1',
    'nv=1/10' => 'Nv/1_10',
    'nv=1/16' => 'Nv/1_16',
    'nv=1/2' => 'Nv/1_2',
    'nv=1/3' => 'Nv/1_3',
    'nv=1/4' => 'Nv/1_4',
    'nv=1/5' => 'Nv/1_5',
    'nv=1/6' => 'Nv/1_6',
    'nv=1/7' => 'Nv/1_7',
    'nv=1/8' => 'Nv/1_8',
    'nv=1/9' => 'Nv/1_9',
    'nv=10' => 'Nv/10',
    'nv=100' => 'Nv/100',
    'nv=1000' => 'Nv/1000',
    'nv=10000' => 'Nv/10000',
    'nv=100000' => 'Nv/100000',
    'nv=100000000' => 'Nv/10000000',
    'nv=1000000000000' => 'Nv/10000002',
    'nv=11' => 'Nv/11',
    'nv=11/2' => 'Nv/11_2',
    'nv=12' => 'Nv/12',
    'nv=13' => 'Nv/13',
    'nv=13/2' => 'Nv/13_2',
    'nv=14' => 'Nv/14',
    'nv=15' => 'Nv/15',
    'nv=15/2' => 'Nv/15_2',
    'nv=16' => 'Nv/16',
    'nv=17' => 'Nv/17',
    'nv=17/2' => 'Nv/17_2',
    'nv=18' => 'Nv/18',
    'nv=19' => 'Nv/19',
    'nv=2' => 'Nv/2',
    'nv=2/3' => 'Nv/2_3',
    'nv=2/5' => 'Nv/2_5',
    'nv=20' => 'Nv/20',
    'nv=200' => 'Nv/200',
    'nv=2000' => 'Nv/2000',
    'nv=20000' => 'Nv/20000',
    'nv=21' => 'Nv/21',
    'nv=22' => 'Nv/22',
    'nv=23' => 'Nv/23',
    'nv=24' => 'Nv/24',
    'nv=25' => 'Nv/25',
    'nv=26' => 'Nv/26',
    'nv=27' => 'Nv/27',
    'nv=28' => 'Nv/28',
    'nv=29' => 'Nv/29',
    'nv=3' => 'Nv/3',
    'nv=3/16' => 'Nv/3_16',
    'nv=3/2' => 'Nv/3_2',
    'nv=3/4' => 'Nv/3_4',
    'nv=3/5' => 'Nv/3_5',
    'nv=3/8' => 'Nv/3_8',
    'nv=30' => 'Nv/30',
    'nv=300' => 'Nv/300',
    'nv=3000' => 'Nv/3000',
    'nv=30000' => 'Nv/30000',
    'nv=31' => 'Nv/31',
    'nv=32' => 'Nv/32',
    'nv=33' => 'Nv/33',
    'nv=34' => 'Nv/34',
    'nv=35' => 'Nv/35',
    'nv=36' => 'Nv/36',
    'nv=37' => 'Nv/37',
    'nv=38' => 'Nv/38',
    'nv=39' => 'Nv/39',
    'nv=4' => 'Nv/4',
    'nv=4/5' => 'Nv/4_5',
    'nv=40' => 'Nv/40',
    'nv=400' => 'Nv/400',
    'nv=4000' => 'Nv/4000',
    'nv=40000' => 'Nv/40000',
    'nv=41' => 'Nv/41',
    'nv=42' => 'Nv/42',
    'nv=43' => 'Nv/43',
    'nv=44' => 'Nv/44',
    'nv=45' => 'Nv/45',
    'nv=46' => 'Nv/46',
    'nv=47' => 'Nv/47',
    'nv=48' => 'Nv/48',
    'nv=49' => 'Nv/49',
    'nv=5' => 'Nv/5',
    'nv=5/2' => 'Nv/5_2',
    'nv=5/6' => 'Nv/5_6',
    'nv=5/8' => 'Nv/5_8',
    'nv=50' => 'Nv/50',
    'nv=500' => 'Nv/500',
    'nv=5000' => 'Nv/5000',
    'nv=50000' => 'Nv/50000',
    'nv=6' => 'Nv/6',
    'nv=60' => 'Nv/60',
    'nv=600' => 'Nv/600',
    'nv=6000' => 'Nv/6000',
    'nv=60000' => 'Nv/60000',
    'nv=7' => 'Nv/7',
    'nv=7/2' => 'Nv/7_2',
    'nv=7/8' => 'Nv/7_8',
    'nv=70' => 'Nv/70',
    'nv=700' => 'Nv/700',
    'nv=7000' => 'Nv/7000',
    'nv=70000' => 'Nv/70000',
    'nv=8' => 'Nv/8',
    'nv=80' => 'Nv/80',
    'nv=800' => 'Nv/800',
    'nv=8000' => 'Nv/8000',
    'nv=80000' => 'Nv/80000',
    'nv=9' => 'Nv/9',
    'nv=9/2' => 'Nv/9_2',
    'nv=90' => 'Nv/90',
    'nv=900' => 'Nv/900',
    'nv=9000' => 'Nv/9000',
    'nv=90000' => 'Nv/90000',
);

# Maps property, table to file for those using loose matching
%utf8::loose_to_file_of = (
    'aegeannumbers' => 'Blk/AegeanNu',
    'age=unassigned' => 'Age/Unassign',
    'ahex' => 'AHex/Y',
    'ahex=f' => 'AHex/N',
    'ahex=false' => 'AHex/N',
    'ahex=n' => 'AHex/N',
    'ahex=no' => 'AHex/N',
    'ahex=t' => 'AHex/Y',
    'ahex=true' => 'AHex/Y',
    'ahex=y' => 'AHex/Y',
    'ahex=yes' => 'AHex/Y',
    'all' => 'Perl/Any',
    'alnum' => 'Perl/Alnum',
    'alpha' => 'Alpha/Y',
    'alpha=f' => 'Alpha/N',
    'alpha=false' => 'Alpha/N',
    'alpha=n' => 'Alpha/N',
    'alpha=no' => 'Alpha/N',
    'alpha=t' => 'Alpha/Y',
    'alpha=true' => 'Alpha/Y',
    'alpha=y' => 'Alpha/Y',
    'alpha=yes' => 'Alpha/Y',
    'alphabetic' => 'Alpha/Y',
    'alphabeticpresentationforms' => 'Blk/Alphabet',
    'ancientgreekmusicalnotation' => 'Blk/Ancient2',
    'ancientgreeknumbers' => 'Blk/AncientG',
    'ancientsymbols' => 'Blk/AncientS',
    'any' => 'Perl/Any',
    'arab' => 'Sc/Arab',
    'arabic' => 'Sc/Arab',
    'arabicpresentationformsa' => 'Blk/ArabicPr',
    'arabicpresentationformsb' => 'Blk/ArabicP2',
    'arabicsupplement' => 'Blk/ArabicSu',
    'armenian' => 'Sc/Armn',
    'armi' => 'Sc/Armi',
    'armn' => 'Sc/Armn',
    'arrows' => 'Blk/Arrows',
    'ascii' => 'Blk/ASCII',
    'asciihexdigit' => 'AHex/Y',
    'assigned' => 'Perl/Assigned',
    'avestan' => 'Sc/Avst',
    'avst' => 'Sc/Avst',
    'bali' => 'Sc/Bali',
    'balinese' => 'Sc/Bali',
    'bamu' => 'Sc/Bamu',
    'bamum' => 'Sc/Bamu',
    'basiclatin' => 'Blk/ASCII',
    'bc=al' => 'Bc/AL',
    'bc=an' => 'Bc/AN',
    'bc=arabicletter' => 'Bc/AL',
    'bc=arabicnumber' => 'Bc/AN',
    'bc=b' => 'Bc/B',
    'bc=bn' => 'Bc/BN',
    'bc=boundaryneutral' => 'Bc/BN',
    'bc=commonseparator' => 'Bc/CS',
    'bc=cs' => 'Bc/CS',
    'bc=en' => 'Bc/EN',
    'bc=es' => 'Bc/ES',
    'bc=et' => 'Bc/ET',
    'bc=europeannumber' => 'Bc/EN',
    'bc=europeanseparator' => 'Bc/ES',
    'bc=europeanterminator' => 'Bc/ET',
    'bc=l' => 'Bc/L',
    'bc=lefttoright' => 'Bc/L',
    'bc=lefttorightembedding' => 'Bc/LRE',
    'bc=lefttorightoverride' => 'Bc/LRO',
    'bc=lre' => 'Bc/LRE',
    'bc=lro' => 'Bc/LRO',
    'bc=nonspacingmark' => 'Bc/NSM',
    'bc=nsm' => 'Bc/NSM',
    'bc=on' => 'Bc/ON',
    'bc=otherneutral' => 'Bc/ON',
    'bc=paragraphseparator' => 'Bc/B',
    'bc=pdf' => 'Bc/PDF',
    'bc=popdirectionalformat' => 'Bc/PDF',
    'bc=r' => 'Bc/R',
    'bc=righttoleft' => 'Bc/R',
    'bc=righttoleftembedding' => 'Bc/RLE',
    'bc=righttoleftoverride' => 'Bc/RLO',
    'bc=rle' => 'Bc/RLE',
    'bc=rlo' => 'Bc/RLO',
    'bc=s' => 'Bc/S',
    'bc=segmentseparator' => 'Bc/S',
    'bc=whitespace' => 'Bc/WS',
    'bc=ws' => 'Bc/WS',
    'beng' => 'Sc/Beng',
    'bengali' => 'Sc/Beng',
    'bidic' => 'BidiC/Y',
    'bidic=f' => 'BidiC/N',
    'bidic=false' => 'BidiC/N',
    'bidic=n' => 'BidiC/N',
    'bidic=no' => 'BidiC/N',
    'bidic=t' => 'BidiC/Y',
    'bidic=true' => 'BidiC/Y',
    'bidic=y' => 'BidiC/Y',
    'bidic=yes' => 'BidiC/Y',
    'bidicontrol' => 'BidiC/Y',
    'bidim' => 'BidiM/Y',
    'bidim=f' => 'BidiM/N',
    'bidim=false' => 'BidiM/N',
    'bidim=n' => 'BidiM/N',
    'bidim=no' => 'BidiM/N',
    'bidim=t' => 'BidiM/Y',
    'bidim=true' => 'BidiM/Y',
    'bidim=y' => 'BidiM/Y',
    'bidim=yes' => 'BidiM/Y',
    'bidimirrored' => 'BidiM/Y',
    'blank' => 'Perl/Blank',
    'blk=aegeannumbers' => 'Blk/AegeanNu',
    'blk=alphabeticpresentationforms' => 'Blk/Alphabet',
    'blk=ancientgreekmusicalnotation' => 'Blk/Ancient2',
    'blk=ancientgreeknumbers' => 'Blk/AncientG',
    'blk=ancientsymbols' => 'Blk/AncientS',
    'blk=arabic' => 'Blk/Arabic',
    'blk=arabicpresentationformsa' => 'Blk/ArabicPr',
    'blk=arabicpresentationformsb' => 'Blk/ArabicP2',
    'blk=arabicsupplement' => 'Blk/ArabicSu',
    'blk=armenian' => 'Blk/Armenian',
    'blk=arrows' => 'Blk/Arrows',
    'blk=ascii' => 'Blk/ASCII',
    'blk=avestan' => 'Blk/Avestan',
    'blk=balinese' => 'Blk/Balinese',
    'blk=bamum' => 'Blk/Bamum',
    'blk=basiclatin' => 'Blk/ASCII',
    'blk=bengali' => 'Blk/Bengali',
    'blk=blockelements' => 'Blk/BlockEle',
    'blk=bopomofo' => 'Blk/Bopomofo',
    'blk=bopomofoextended' => 'Blk/Bopomof2',
    'blk=boxdrawing' => 'Blk/BoxDrawi',
    'blk=braillepatterns' => 'Blk/BrailleP',
    'blk=buginese' => 'Blk/Buginese',
    'blk=buhid' => 'Blk/Buhid',
    'blk=byzantinemusicalsymbols' => 'Blk/Byzantin',
    'blk=canadiansyllabics' => 'Blk/Canadian',
    'blk=carian' => 'Blk/Carian',
    'blk=cham' => 'Blk/Cham',
    'blk=cherokee' => 'Blk/Cherokee',
    'blk=cjkcompatibility' => 'Blk/CJKCompa',
    'blk=cjkcompatibilityforms' => 'Blk/CJKComp2',
    'blk=cjkcompatibilityideographs' => 'Blk/CJKComp3',
    'blk=cjkcompatibilityideographssupplement' => 'Blk/CJKComp4',
    'blk=cjkradicalssupplement' => 'Blk/CJKRadic',
    'blk=cjkstrokes' => 'Blk/CJKStrok',
    'blk=cjksymbolsandpunctuation' => 'Blk/CJKSymbo',
    'blk=cjkunifiedideographs' => 'Blk/CJKUnifi',
    'blk=cjkunifiedideographsextensiona' => 'Blk/CJKUnif2',
    'blk=cjkunifiedideographsextensionb' => 'Blk/CJKUnif3',
    'blk=cjkunifiedideographsextensionc' => 'Blk/CJKUnif4',
    'blk=combiningdiacriticalmarks' => 'Blk/Combini3',
    'blk=combiningdiacriticalmarksforsymbols' => 'Blk/Combini2',
    'blk=combiningdiacriticalmarkssupplement' => 'Blk/Combini4',
    'blk=combininghalfmarks' => 'Blk/Combinin',
    'blk=combiningmarksforsymbols' => 'Blk/Combini2',
    'blk=commonindicnumberforms' => 'Blk/CommonIn',
    'blk=controlpictures' => 'Blk/ControlP',
    'blk=coptic' => 'Blk/Coptic',
    'blk=countingrodnumerals' => 'Blk/Counting',
    'blk=cuneiform' => 'Blk/Cuneifor',
    'blk=cuneiformnumbersandpunctuation' => 'Blk/Cuneifo2',
    'blk=currencysymbols' => 'Blk/Currency',
    'blk=cypriotsyllabary' => 'Blk/CypriotS',
    'blk=cyrillic' => 'Blk/Cyrillic',
    'blk=cyrillicextendeda' => 'Blk/Cyrilli2',
    'blk=cyrillicextendedb' => 'Blk/Cyrilli3',
    'blk=cyrillicsupplement' => 'Blk/Cyrilli4',
    'blk=cyrillicsupplementary' => 'Blk/Cyrilli4',
    'blk=deseret' => 'Blk/Deseret',
    'blk=devanagari' => 'Blk/Devanaga',
    'blk=devanagariextended' => 'Blk/Devanag2',
    'blk=dingbats' => 'Blk/Dingbats',
    'blk=dominotiles' => 'Blk/DominoTi',
    'blk=egyptianhieroglyphs' => 'Blk/Egyptian',
    'blk=enclosedalphanumerics' => 'Blk/Enclosed',
    'blk=enclosedalphanumericsupplement' => 'Blk/Enclose4',
    'blk=enclosedcjklettersandmonths' => 'Blk/Enclose2',
    'blk=enclosedideographicsupplement' => 'Blk/Enclose3',
    'blk=ethiopic' => 'Blk/Ethiopic',
    'blk=ethiopicextended' => 'Blk/Ethiopi2',
    'blk=ethiopicsupplement' => 'Blk/Ethiopi3',
    'blk=generalpunctuation' => 'Blk/GeneralP',
    'blk=geometricshapes' => 'Blk/Geometri',
    'blk=georgian' => 'Blk/Georgian',
    'blk=georgiansupplement' => 'Blk/Georgia2',
    'blk=glagolitic' => 'Blk/Glagolit',
    'blk=gothic' => 'Blk/Gothic',
    'blk=greek' => 'Blk/Greek',
    'blk=greekandcoptic' => 'Blk/Greek',
    'blk=greekextended' => 'Blk/GreekExt',
    'blk=gujarati' => 'Blk/Gujarati',
    'blk=gurmukhi' => 'Blk/Gurmukhi',
    'blk=halfwidthandfullwidthforms' => 'Blk/Halfwidt',
    'blk=hangulcompatibilityjamo' => 'Blk/HangulCo',
    'blk=hanguljamo' => 'Blk/HangulJa',
    'blk=hanguljamoextendeda' => 'Blk/HangulJ2',
    'blk=hanguljamoextendedb' => 'Blk/HangulJ3',
    'blk=hangulsyllables' => 'Blk/HangulSy',
    'blk=hanunoo' => 'Blk/Hanunoo',
    'blk=hebrew' => 'Blk/Hebrew',
    'blk=highprivateusesurrogates' => 'Blk/HighPriv',
    'blk=highsurrogates' => 'Blk/HighSurr',
    'blk=hiragana' => 'Blk/Hiragana',
    'blk=ideographicdescriptioncharacters' => 'Blk/Ideograp',
    'blk=imperialaramaic' => 'Blk/Imperial',
    'blk=inscriptionalpahlavi' => 'Blk/Inscript',
    'blk=inscriptionalparthian' => 'Blk/Inscrip2',
    'blk=ipaextensions' => 'Blk/IPAExten',
    'blk=javanese' => 'Blk/Javanese',
    'blk=kaithi' => 'Blk/Kaithi',
    'blk=kanbun' => 'Blk/Kanbun',
    'blk=kangxiradicals' => 'Blk/KangxiRa',
    'blk=kannada' => 'Blk/Kannada',
    'blk=katakana' => 'Blk/Katakana',
    'blk=katakanaphoneticextensions' => 'Blk/Katakan2',
    'blk=kayahli' => 'Blk/KayahLi',
    'blk=kharoshthi' => 'Blk/Kharosht',
    'blk=khmer' => 'Blk/Khmer',
    'blk=khmersymbols' => 'Blk/KhmerSym',
    'blk=lao' => 'Blk/Lao',
    'blk=latin1' => 'Blk/Latin1',
    'blk=latin1supplement' => 'Blk/Latin1',
    'blk=latinextendeda' => 'Blk/LatinExt',
    'blk=latinextendedadditional' => 'Blk/LatinEx5',
    'blk=latinextendedb' => 'Blk/LatinEx2',
    'blk=latinextendedc' => 'Blk/LatinEx3',
    'blk=latinextendedd' => 'Blk/LatinEx4',
    'blk=lepcha' => 'Blk/Lepcha',
    'blk=letterlikesymbols' => 'Blk/Letterli',
    'blk=limbu' => 'Blk/Limbu',
    'blk=linearbideograms' => 'Blk/LinearBI',
    'blk=linearbsyllabary' => 'Blk/LinearBS',
    'blk=lisu' => 'Blk/Lisu',
    'blk=lowsurrogates' => 'Blk/LowSurro',
    'blk=lycian' => 'Blk/Lycian',
    'blk=lydian' => 'Blk/Lydian',
    'blk=mahjongtiles' => 'Blk/MahjongT',
    'blk=malayalam' => 'Blk/Malayala',
    'blk=mathematicalalphanumericsymbols' => 'Blk/Mathema2',
    'blk=mathematicaloperators' => 'Blk/Mathemat',
    'blk=meeteimayek' => 'Blk/MeeteiMa',
    'blk=miscellaneousmathematicalsymbolsa' => 'Blk/Miscell4',
    'blk=miscellaneousmathematicalsymbolsb' => 'Blk/Miscell5',
    'blk=miscellaneoussymbols' => 'Blk/Miscella',
    'blk=miscellaneoussymbolsandarrows' => 'Blk/Miscell3',
    'blk=miscellaneoustechnical' => 'Blk/Miscell2',
    'blk=modifiertoneletters' => 'Blk/Modifier',
    'blk=mongolian' => 'Blk/Mongolia',
    'blk=musicalsymbols' => 'Blk/MusicalS',
    'blk=myanmar' => 'Blk/Myanmar',
    'blk=myanmarextendeda' => 'Blk/MyanmarE',
    'blk=newtailue' => 'Blk/NewTaiLu',
    'blk=nko' => 'Blk/NKo',
    'blk=noblock' => 'Blk/NoBlock',
    'blk=numberforms' => 'Blk/NumberFo',
    'blk=ogham' => 'Blk/Ogham',
    'blk=olchiki' => 'Blk/OlChiki',
    'blk=olditalic' => 'Blk/OldItali',
    'blk=oldpersian' => 'Blk/OldPersi',
    'blk=oldsoutharabian' => 'Blk/OldSouth',
    'blk=oldturkic' => 'Blk/OldTurki',
    'blk=opticalcharacterrecognition' => 'Blk/OpticalC',
    'blk=oriya' => 'Blk/Oriya',
    'blk=osmanya' => 'Blk/Osmanya',
    'blk=phagspa' => 'Blk/PhagsPa',
    'blk=phaistosdisc' => 'Blk/Phaistos',
    'blk=phoenician' => 'Blk/Phoenici',
    'blk=phoneticextensions' => 'Blk/Phonetic',
    'blk=phoneticextensionssupplement' => 'Blk/Phoneti2',
    'blk=privateuse' => 'Blk/PrivateU',
    'blk=privateusearea' => 'Blk/PrivateU',
    'blk=rejang' => 'Blk/Rejang',
    'blk=ruminumeralsymbols' => 'Blk/RumiNume',
    'blk=runic' => 'Blk/Runic',
    'blk=samaritan' => 'Blk/Samarita',
    'blk=saurashtra' => 'Blk/Saurasht',
    'blk=shavian' => 'Blk/Shavian',
    'blk=sinhala' => 'Blk/Sinhala',
    'blk=smallformvariants' => 'Blk/SmallFor',
    'blk=spacingmodifierletters' => 'Blk/SpacingM',
    'blk=specials' => 'Blk/Specials',
    'blk=sundanese' => 'Blk/Sundanes',
    'blk=superscriptsandsubscripts' => 'Blk/Superscr',
    'blk=supplementalarrowsa' => 'Blk/Suppleme',
    'blk=supplementalarrowsb' => 'Blk/Supplem2',
    'blk=supplementalmathematicaloperators' => 'Blk/Supplem6',
    'blk=supplementalpunctuation' => 'Blk/Supplem3',
    'blk=supplementaryprivateuseareaa' => 'Blk/Supplem4',
    'blk=supplementaryprivateuseareab' => 'Blk/Supplem5',
    'blk=sylotinagri' => 'Blk/SylotiNa',
    'blk=syriac' => 'Blk/Syriac',
    'blk=tagalog' => 'Blk/Tagalog',
    'blk=tagbanwa' => 'Blk/Tagbanwa',
    'blk=tags' => 'Blk/Tags',
    'blk=taile' => 'Blk/TaiLe',
    'blk=taitham' => 'Blk/TaiTham',
    'blk=taiviet' => 'Blk/TaiViet',
    'blk=taixuanjingsymbols' => 'Blk/TaiXuanJ',
    'blk=tamil' => 'Blk/Tamil',
    'blk=telugu' => 'Blk/Telugu',
    'blk=thaana' => 'Blk/Thaana',
    'blk=thai' => 'Blk/Thai',
    'blk=tibetan' => 'Blk/Tibetan',
    'blk=tifinagh' => 'Blk/Tifinagh',
    'blk=ugaritic' => 'Blk/Ugaritic',
    'blk=unifiedcanadianaboriginalsyllabics' => 'Blk/Canadian',
    'blk=unifiedcanadianaboriginalsyllabicsextended' => 'Blk/UnifiedC',
    'blk=vai' => 'Blk/Vai',
    'blk=variationselectors' => 'Blk/Variatio',
    'blk=variationselectorssupplement' => 'Blk/Variati2',
    'blk=vedicextensions' => 'Blk/VedicExt',
    'blk=verticalforms' => 'Blk/Vertical',
    'blk=yijinghexagramsymbols' => 'Blk/YijingHe',
    'blk=yiradicals' => 'Blk/YiRadica',
    'blk=yisyllables' => 'Blk/YiSyllab',
    'blockelements' => 'Blk/BlockEle',
    'bopo' => 'Sc/Bopo',
    'bopomofo' => 'Sc/Bopo',
    'bopomofoextended' => 'Blk/Bopomof2',
    'boxdrawing' => 'Blk/BoxDrawi',
    'brai' => 'Blk/BrailleP',
    'braille' => 'Blk/BrailleP',
    'braillepatterns' => 'Blk/BrailleP',
    'bugi' => 'Sc/Bugi',
    'buginese' => 'Sc/Bugi',
    'buhd' => 'Sc/Buhd',
    'buhid' => 'Sc/Buhd',
    'byzantinemusicalsymbols' => 'Blk/Byzantin',
    'c' => 'Gc/C',
    'canadianaboriginal' => 'Sc/Cans',
    'canadiansyllabics' => 'Blk/Canadian',
    'cans' => 'Sc/Cans',
    'cari' => 'Sc/Cari',
    'carian' => 'Sc/Cari',
    'cased' => 'Cased/Y',
    'cased=f' => 'Cased/N',
    'cased=false' => 'Cased/N',
    'cased=n' => 'Cased/N',
    'cased=no' => 'Cased/N',
    'cased=t' => 'Cased/Y',
    'cased=true' => 'Cased/Y',
    'cased=y' => 'Cased/Y',
    'cased=yes' => 'Cased/Y',
    'casedletter' => 'Gc/LC',
    'caseignorable' => 'CI/Y',
    'cc' => 'Gc/Cc',
    'ccc=a' => 'Ccc/A',
    'ccc=above' => 'Ccc/A',
    'ccc=aboveleft' => 'Ccc/AL',
    'ccc=aboveright' => 'Ccc/AR',
    'ccc=al' => 'Ccc/AL',
    'ccc=ar' => 'Ccc/AR',
    'ccc=ata' => 'Ccc/ATA',
    'ccc=atar' => 'Ccc/ATAR',
    'ccc=atb' => 'Ccc/ATB',
    'ccc=atbl' => 'Ccc/ATBL',
    'ccc=attachedabove' => 'Ccc/ATA',
    'ccc=attachedaboveright' => 'Ccc/ATAR',
    'ccc=attachedbelow' => 'Ccc/ATB',
    'ccc=attachedbelowleft' => 'Ccc/ATBL',
    'ccc=b' => 'Ccc/B',
    'ccc=below' => 'Ccc/B',
    'ccc=belowleft' => 'Ccc/BL',
    'ccc=belowright' => 'Ccc/BR',
    'ccc=bl' => 'Ccc/BL',
    'ccc=br' => 'Ccc/BR',
    'ccc=da' => 'Ccc/DA',
    'ccc=db' => 'Ccc/DB',
    'ccc=doubleabove' => 'Ccc/DA',
    'ccc=doublebelow' => 'Ccc/DB',
    'ccc=iotasubscript' => 'Ccc/IS',
    'ccc=is' => 'Ccc/IS',
    'ccc=kanavoicing' => 'Ccc/KV',
    'ccc=kv' => 'Ccc/KV',
    'ccc=l' => 'Ccc/L',
    'ccc=left' => 'Ccc/L',
    'ccc=nk' => 'Ccc/NK',
    'ccc=notreordered' => 'Ccc/NR',
    'ccc=nr' => 'Ccc/NR',
    'ccc=nukta' => 'Ccc/NK',
    'ccc=ov' => 'Ccc/OV',
    'ccc=overlay' => 'Ccc/OV',
    'ccc=r' => 'Ccc/R',
    'ccc=right' => 'Ccc/R',
    'ccc=virama' => 'Ccc/VR',
    'ccc=vr' => 'Ccc/VR',
    'ce' => 'CE/Y',
    'ce=f' => 'CE/N',
    'ce=false' => 'CE/N',
    'ce=n' => 'CE/N',
    'ce=no' => 'CE/N',
    'ce=t' => 'CE/Y',
    'ce=true' => 'CE/Y',
    'ce=y' => 'CE/Y',
    'ce=yes' => 'CE/Y',
    'cf' => 'Gc/Cf',
    'cham' => 'Sc/Cham',
    'changeswhencasefolded' => 'CWCF/Y',
    'changeswhencasemapped' => 'CWCM/Y',
    'changeswhenlowercased' => 'CWL/Y',
    'changeswhennfkccasefolded' => 'CWKCF/Y',
    'changeswhentitlecased' => 'CWT/Y',
    'changeswhenuppercased' => 'CWU/Y',
    'cher' => 'Sc/Cher',
    'cherokee' => 'Sc/Cher',
    'ci' => 'CI/Y',
    'ci=f' => 'CI/N',
    'ci=false' => 'CI/N',
    'ci=n' => 'CI/N',
    'ci=no' => 'CI/N',
    'ci=t' => 'CI/Y',
    'ci=true' => 'CI/Y',
    'ci=y' => 'CI/Y',
    'ci=yes' => 'CI/Y',
    'cjkcompatibility' => 'Blk/CJKCompa',
    'cjkcompatibilityforms' => 'Blk/CJKComp2',
    'cjkcompatibilityideographs' => 'Blk/CJKComp3',
    'cjkcompatibilityideographssupplement' => 'Blk/CJKComp4',
    'cjkradicalssupplement' => 'Blk/CJKRadic',
    'cjkstrokes' => 'Blk/CJKStrok',
    'cjksymbolsandpunctuation' => 'Blk/CJKSymbo',
    'cjkunifiedideographs' => 'Blk/CJKUnifi',
    'cjkunifiedideographsextensiona' => 'Blk/CJKUnif2',
    'cjkunifiedideographsextensionb' => 'Blk/CJKUnif3',
    'cjkunifiedideographsextensionc' => 'Blk/CJKUnif4',
    'closepunctuation' => 'Gc/Pe',
    'cn' => 'Gc/Cn',
    'cntrl' => 'Gc/Cc',
    'co' => 'Gc/Co',
    'combiningdiacriticalmarks' => 'Blk/Combini3',
    'combiningdiacriticalmarksforsymbols' => 'Blk/Combini2',
    'combiningdiacriticalmarkssupplement' => 'Blk/Combini4',
    'combininghalfmarks' => 'Blk/Combinin',
    'combiningmarksforsymbols' => 'Blk/Combini2',
    'common' => 'Sc/Zyyy',
    'commonindicnumberforms' => 'Blk/CommonIn',
    'compex' => 'CompEx/Y',
    'compex=f' => 'CompEx/N',
    'compex=false' => 'CompEx/N',
    'compex=n' => 'CompEx/N',
    'compex=no' => 'CompEx/N',
    'compex=t' => 'CompEx/Y',
    'compex=true' => 'CompEx/Y',
    'compex=y' => 'CompEx/Y',
    'compex=yes' => 'CompEx/Y',
    'compositionexclusion' => 'CE/Y',
    'connectorpunctuation' => 'WB/EX',
    'control' => 'Gc/Cc',
    'controlpictures' => 'Blk/ControlP',
    'copt' => 'Sc/Copt',
    'coptic' => 'Sc/Copt',
    'countingrodnumerals' => 'Blk/Counting',
    'cprt' => 'Sc/Cprt',
    'cs' => 'Gc/Cs',
    'cuneiform' => 'Sc/Xsux',
    'cuneiformnumbersandpunctuation' => 'Blk/Cuneifo2',
    'currencysymbol' => 'Gc/Sc',
    'currencysymbols' => 'Blk/Currency',
    'cwcf' => 'CWCF/Y',
    'cwcf=f' => 'CWCF/N',
    'cwcf=false' => 'CWCF/N',
    'cwcf=n' => 'CWCF/N',
    'cwcf=no' => 'CWCF/N',
    'cwcf=t' => 'CWCF/Y',
    'cwcf=true' => 'CWCF/Y',
    'cwcf=y' => 'CWCF/Y',
    'cwcf=yes' => 'CWCF/Y',
    'cwcm' => 'CWCM/Y',
    'cwcm=f' => 'CWCM/N',
    'cwcm=false' => 'CWCM/N',
    'cwcm=n' => 'CWCM/N',
    'cwcm=no' => 'CWCM/N',
    'cwcm=t' => 'CWCM/Y',
    'cwcm=true' => 'CWCM/Y',
    'cwcm=y' => 'CWCM/Y',
    'cwcm=yes' => 'CWCM/Y',
    'cwkcf' => 'CWKCF/Y',
    'cwkcf=f' => 'CWKCF/N',
    'cwkcf=false' => 'CWKCF/N',
    'cwkcf=n' => 'CWKCF/N',
    'cwkcf=no' => 'CWKCF/N',
    'cwkcf=t' => 'CWKCF/Y',
    'cwkcf=true' => 'CWKCF/Y',
    'cwkcf=y' => 'CWKCF/Y',
    'cwkcf=yes' => 'CWKCF/Y',
    'cwl' => 'CWL/Y',
    'cwl=f' => 'CWL/N',
    'cwl=false' => 'CWL/N',
    'cwl=n' => 'CWL/N',
    'cwl=no' => 'CWL/N',
    'cwl=t' => 'CWL/Y',
    'cwl=true' => 'CWL/Y',
    'cwl=y' => 'CWL/Y',
    'cwl=yes' => 'CWL/Y',
    'cwt' => 'CWT/Y',
    'cwt=f' => 'CWT/N',
    'cwt=false' => 'CWT/N',
    'cwt=n' => 'CWT/N',
    'cwt=no' => 'CWT/N',
    'cwt=t' => 'CWT/Y',
    'cwt=true' => 'CWT/Y',
    'cwt=y' => 'CWT/Y',
    'cwt=yes' => 'CWT/Y',
    'cwu' => 'CWU/Y',
    'cwu=f' => 'CWU/N',
    'cwu=false' => 'CWU/N',
    'cwu=n' => 'CWU/N',
    'cwu=no' => 'CWU/N',
    'cwu=t' => 'CWU/Y',
    'cwu=true' => 'CWU/Y',
    'cwu=y' => 'CWU/Y',
    'cwu=yes' => 'CWU/Y',
    'cypriot' => 'Sc/Cprt',
    'cypriotsyllabary' => 'Blk/CypriotS',
    'cyrillic' => 'Sc/Cyrl',
    'cyrillicextendeda' => 'Blk/Cyrilli2',
    'cyrillicextendedb' => 'Blk/Cyrilli3',
    'cyrillicsupplement' => 'Blk/Cyrilli4',
    'cyrillicsupplementary' => 'Blk/Cyrilli4',
    'cyrl' => 'Sc/Cyrl',
    'dash' => 'Dash/Y',
    'dash=f' => 'Dash/N',
    'dash=false' => 'Dash/N',
    'dash=n' => 'Dash/N',
    'dash=no' => 'Dash/N',
    'dash=t' => 'Dash/Y',
    'dash=true' => 'Dash/Y',
    'dash=y' => 'Dash/Y',
    'dash=yes' => 'Dash/Y',
    'dashpunctuation' => 'Gc/Pd',
    'decimalnumber' => 'Nt/De',
    'defaultignorablecodepoint' => 'DI/Y',
    'dep' => 'Dep/Y',
    'dep=f' => 'Dep/N',
    'dep=false' => 'Dep/N',
    'dep=n' => 'Dep/N',
    'dep=no' => 'Dep/N',
    'dep=t' => 'Dep/Y',
    'dep=true' => 'Dep/Y',
    'dep=y' => 'Dep/Y',
    'dep=yes' => 'Dep/Y',
    'deprecated' => 'Dep/Y',
    'deseret' => 'Blk/Deseret',
    'deva' => 'Sc/Deva',
    'devanagari' => 'Sc/Deva',
    'devanagariextended' => 'Blk/Devanag2',
    'di' => 'DI/Y',
    'di=f' => 'DI/N',
    'di=false' => 'DI/N',
    'di=n' => 'DI/N',
    'di=no' => 'DI/N',
    'di=t' => 'DI/Y',
    'di=true' => 'DI/Y',
    'di=y' => 'DI/Y',
    'di=yes' => 'DI/Y',
    'dia' => 'Dia/Y',
    'dia=f' => 'Dia/N',
    'dia=false' => 'Dia/N',
    'dia=n' => 'Dia/N',
    'dia=no' => 'Dia/N',
    'dia=t' => 'Dia/Y',
    'dia=true' => 'Dia/Y',
    'dia=y' => 'Dia/Y',
    'dia=yes' => 'Dia/Y',
    'diacritic' => 'Dia/Y',
    'digit' => 'Nt/De',
    'dingbats' => 'Blk/Dingbats',
    'dominotiles' => 'Blk/DominoTi',
    'dsrt' => 'Blk/Deseret',
    'dt=can' => 'NFDQC/N',
    'dt=canonical' => 'NFDQC/N',
    'dt=circle' => 'Dt/Enc',
    'dt=com' => 'Dt/Com',
    'dt=compat' => 'Dt/Com',
    'dt=enc' => 'Dt/Enc',
    'dt=fin' => 'Dt/Fin',
    'dt=final' => 'Dt/Fin',
    'dt=font' => 'Dt/Font',
    'dt=fra' => 'Dt/Fra',
    'dt=fraction' => 'Dt/Fra',
    'dt=init' => 'Dt/Init',
    'dt=initial' => 'Dt/Init',
    'dt=iso' => 'Dt/Iso',
    'dt=isolated' => 'Dt/Iso',
    'dt=med' => 'Dt/Med',
    'dt=medial' => 'Dt/Med',
    'dt=nar' => 'Dt/Nar',
    'dt=narrow' => 'Dt/Nar',
    'dt=nb' => 'Dt/Nb',
    'dt=nobreak' => 'Dt/Nb',
    'dt=noncanon' => 'Dt/NonCanon',
    'dt=noncanonical' => 'Dt/NonCanon',
    'dt=none' => 'Dt/None',
    'dt=small' => 'Dt/Sml',
    'dt=sml' => 'Dt/Sml',
    'dt=sqr' => 'Dt/Sqr',
    'dt=square' => 'Dt/Sqr',
    'dt=sub' => 'Dt/Sub',
    'dt=sup' => 'Dt/Sup',
    'dt=super' => 'Dt/Sup',
    'dt=vert' => 'Dt/Vert',
    'dt=vertical' => 'Dt/Vert',
    'dt=wide' => 'Ea/F',
    'ea=a' => 'Ea/A',
    'ea=ambiguous' => 'Ea/A',
    'ea=f' => 'Ea/F',
    'ea=fullwidth' => 'Ea/F',
    'ea=h' => 'Ea/H',
    'ea=halfwidth' => 'Ea/H',
    'ea=n' => 'Ea/N',
    'ea=na' => 'Ea/Na',
    'ea=narrow' => 'Ea/Na',
    'ea=neutral' => 'Ea/N',
    'ea=w' => 'Ea/W',
    'ea=wide' => 'Ea/W',
    'egyp' => 'Sc/Egyp',
    'egyptianhieroglyphs' => 'Sc/Egyp',
    'enclosedalphanumerics' => 'Blk/Enclosed',
    'enclosedalphanumericsupplement' => 'Blk/Enclose4',
    'enclosedcjklettersandmonths' => 'Blk/Enclose2',
    'enclosedideographicsupplement' => 'Blk/Enclose3',
    'enclosingmark' => 'Gc/Me',
    'ethi' => 'Sc/Ethi',
    'ethiopic' => 'Sc/Ethi',
    'ethiopicextended' => 'Blk/Ethiopi2',
    'ethiopicsupplement' => 'Blk/Ethiopi3',
    'ext' => 'Ext/Y',
    'ext=f' => 'Ext/N',
    'ext=false' => 'Ext/N',
    'ext=n' => 'Ext/N',
    'ext=no' => 'Ext/N',
    'ext=t' => 'Ext/Y',
    'ext=true' => 'Ext/Y',
    'ext=y' => 'Ext/Y',
    'ext=yes' => 'Ext/Y',
    'extender' => 'Ext/Y',
    'finalpunctuation' => 'Gc/Pf',
    'format' => 'Gc/Cf',
    'fullcompositionexclusion' => 'CompEx/Y',
    'gc=c' => 'Gc/C',
    'gc=casedletter' => 'Gc/LC',
    'gc=cc' => 'Gc/Cc',
    'gc=cf' => 'Gc/Cf',
    'gc=closepunctuation' => 'Gc/Pe',
    'gc=cn' => 'Gc/Cn',
    'gc=cntrl' => 'Gc/Cc',
    'gc=co' => 'Gc/Co',
    'gc=connectorpunctuation' => 'WB/EX',
    'gc=control' => 'Gc/Cc',
    'gc=cs' => 'Gc/Cs',
    'gc=currencysymbol' => 'Gc/Sc',
    'gc=dashpunctuation' => 'Gc/Pd',
    'gc=decimalnumber' => 'Nt/De',
    'gc=digit' => 'Nt/De',
    'gc=enclosingmark' => 'Gc/Me',
    'gc=finalpunctuation' => 'Gc/Pf',
    'gc=format' => 'Gc/Cf',
    'gc=initialpunctuation' => 'Gc/Pi',
    'gc=l' => 'Gc/L',
    'gc=l&' => 'Gc/LC',
    'gc=l_' => 'Gc/LC',
    'gc=lc' => 'Gc/LC',
    'gc=letter' => 'Gc/L',
    'gc=letternumber' => 'Gc/Nl',
    'gc=lineseparator' => 'Gc/Zl',
    'gc=ll' => 'Gc/Ll',
    'gc=lm' => 'Gc/Lm',
    'gc=lo' => 'Gc/Lo',
    'gc=lowercaseletter' => 'Gc/Ll',
    'gc=lt' => 'Gc/Lt',
    'gc=lu' => 'Gc/Lu',
    'gc=m' => 'Gc/M',
    'gc=mark' => 'Gc/M',
    'gc=mathsymbol' => 'Gc/Sm',
    'gc=mc' => 'Gc/Mc',
    'gc=me' => 'Gc/Me',
    'gc=mn' => 'Gc/Mn',
    'gc=modifierletter' => 'Gc/Lm',
    'gc=modifiersymbol' => 'Gc/Sk',
    'gc=n' => 'Gc/N',
    'gc=nd' => 'Nt/De',
    'gc=nl' => 'Gc/Nl',
    'gc=no' => 'Gc/No',
    'gc=nonspacingmark' => 'Gc/Mn',
    'gc=number' => 'Gc/N',
    'gc=openpunctuation' => 'Gc/Ps',
    'gc=other' => 'Gc/C',
    'gc=otherletter' => 'Gc/Lo',
    'gc=othernumber' => 'Gc/No',
    'gc=otherpunctuation' => 'Gc/Po',
    'gc=othersymbol' => 'Gc/So',
    'gc=p' => 'Gc/P',
    'gc=paragraphseparator' => 'Gc/Zp',
    'gc=pc' => 'WB/EX',
    'gc=pd' => 'Gc/Pd',
    'gc=pe' => 'Gc/Pe',
    'gc=pf' => 'Gc/Pf',
    'gc=pi' => 'Gc/Pi',
    'gc=po' => 'Gc/Po',
    'gc=privateuse' => 'Gc/Co',
    'gc=ps' => 'Gc/Ps',
    'gc=punct' => 'Gc/P',
    'gc=punctuation' => 'Gc/P',
    'gc=s' => 'Gc/S',
    'gc=sc' => 'Gc/Sc',
    'gc=separator' => 'Gc/Z',
    'gc=sk' => 'Gc/Sk',
    'gc=sm' => 'Gc/Sm',
    'gc=so' => 'Gc/So',
    'gc=spaceseparator' => 'Gc/Zs',
    'gc=spacingmark' => 'Gc/Mc',
    'gc=surrogate' => 'Gc/Cs',
    'gc=symbol' => 'Gc/S',
    'gc=titlecaseletter' => 'Gc/Lt',
    'gc=unassigned' => 'Gc/Cn',
    'gc=uppercaseletter' => 'Gc/Lu',
    'gc=z' => 'Gc/Z',
    'gc=zl' => 'Gc/Zl',
    'gc=zp' => 'Gc/Zp',
    'gc=zs' => 'Gc/Zs',
    'gcb=cn' => 'GCB/CN',
    'gcb=control' => 'GCB/CN',
    'gcb=cr' => 'GCB/CR',
    'gcb=ex' => 'GCB/EX',
    'gcb=extend' => 'GCB/EX',
    'gcb=l' => 'GCB/L',
    'gcb=lf' => 'GCB/LF',
    'gcb=lv' => 'GCB/LV',
    'gcb=lvt' => 'GCB/LVT',
    'gcb=other' => 'GCB/XX',
    'gcb=pp' => 'GCB/PP',
    'gcb=prepend' => 'GCB/PP',
    'gcb=sm' => 'GCB/SM',
    'gcb=spacingmark' => 'GCB/SM',
    'gcb=t' => 'GCB/T',
    'gcb=v' => 'GCB/V',
    'gcb=xx' => 'GCB/XX',
    'generalpunctuation' => 'Blk/GeneralP',
    'geometricshapes' => 'Blk/Geometri',
    'geor' => 'Sc/Geor',
    'georgian' => 'Sc/Geor',
    'georgiansupplement' => 'Blk/Georgia2',
    'glag' => 'Sc/Glag',
    'glagolitic' => 'Sc/Glag',
    'goth' => 'Sc/Goth',
    'gothic' => 'Sc/Goth',
    'graph' => 'Perl/Graph',
    'graphemebase' => 'GrBase/Y',
    'graphemeextend' => 'GrExt/Y',
    'grbase' => 'GrBase/Y',
    'grbase=f' => 'GrBase/N',
    'grbase=false' => 'GrBase/N',
    'grbase=n' => 'GrBase/N',
    'grbase=no' => 'GrBase/N',
    'grbase=t' => 'GrBase/Y',
    'grbase=true' => 'GrBase/Y',
    'grbase=y' => 'GrBase/Y',
    'grbase=yes' => 'GrBase/Y',
    'greek' => 'Sc/Grek',
    'greekandcoptic' => 'Blk/Greek',
    'greekextended' => 'Blk/GreekExt',
    'grek' => 'Sc/Grek',
    'grext' => 'GrExt/Y',
    'grext=f' => 'GrExt/N',
    'grext=false' => 'GrExt/N',
    'grext=n' => 'GrExt/N',
    'grext=no' => 'GrExt/N',
    'grext=t' => 'GrExt/Y',
    'grext=true' => 'GrExt/Y',
    'grext=y' => 'GrExt/Y',
    'grext=yes' => 'GrExt/Y',
    'gujarati' => 'Sc/Gujr',
    'gujr' => 'Sc/Gujr',
    'gurmukhi' => 'Sc/Guru',
    'guru' => 'Sc/Guru',
    'halfwidthandfullwidthforms' => 'Blk/Halfwidt',
    'han' => 'Sc/Han',
    'hang' => 'Sc/Hang',
    'hangul' => 'Sc/Hang',
    'hangulcompatibilityjamo' => 'Blk/HangulCo',
    'hanguljamo' => 'Blk/HangulJa',
    'hanguljamoextendeda' => 'Blk/HangulJ2',
    'hanguljamoextendedb' => 'Blk/HangulJ3',
    'hangulsyllables' => 'Blk/HangulSy',
    'hani' => 'Sc/Han',
    'hano' => 'Sc/Hano',
    'hanunoo' => 'Sc/Hano',
    'hebr' => 'Sc/Hebr',
    'hebrew' => 'Sc/Hebr',
    'hex' => 'Hex/Y',
    'hex=f' => 'Hex/N',
    'hex=false' => 'Hex/N',
    'hex=n' => 'Hex/N',
    'hex=no' => 'Hex/N',
    'hex=t' => 'Hex/Y',
    'hex=true' => 'Hex/Y',
    'hex=y' => 'Hex/Y',
    'hex=yes' => 'Hex/Y',
    'hexdigit' => 'Hex/Y',
    'highprivateusesurrogates' => 'Blk/HighPriv',
    'highsurrogates' => 'Blk/HighSurr',
    'hira' => 'Sc/Hira',
    'hiragana' => 'Sc/Hira',
    'horizspace' => 'Perl/Blank',
    'hst=l' => 'GCB/L',
    'hst=leadingjamo' => 'GCB/L',
    'hst=lv' => 'GCB/LV',
    'hst=lvsyllable' => 'GCB/LV',
    'hst=lvt' => 'GCB/LVT',
    'hst=lvtsyllable' => 'GCB/LVT',
    'hst=na' => 'Hst/NA',
    'hst=notapplicable' => 'Hst/NA',
    'hst=t' => 'GCB/T',
    'hst=trailingjamo' => 'GCB/T',
    'hst=v' => 'GCB/V',
    'hst=voweljamo' => 'GCB/V',
    'hyphen' => 'Hyphen/Y',
    'hyphen=f' => 'Hyphen/N',
    'hyphen=false' => 'Hyphen/N',
    'hyphen=n' => 'Hyphen/N',
    'hyphen=no' => 'Hyphen/N',
    'hyphen=t' => 'Hyphen/Y',
    'hyphen=true' => 'Hyphen/Y',
    'hyphen=y' => 'Hyphen/Y',
    'hyphen=yes' => 'Hyphen/Y',
    'idc' => 'IDC/Y',
    'idc=f' => 'IDC/N',
    'idc=false' => 'IDC/N',
    'idc=n' => 'IDC/N',
    'idc=no' => 'IDC/N',
    'idc=t' => 'IDC/Y',
    'idc=true' => 'IDC/Y',
    'idc=y' => 'IDC/Y',
    'idc=yes' => 'IDC/Y',
    'idcontinue' => 'IDC/Y',
    'ideo' => 'Ideo/Y',
    'ideo=f' => 'Ideo/N',
    'ideo=false' => 'Ideo/N',
    'ideo=n' => 'Ideo/N',
    'ideo=no' => 'Ideo/N',
    'ideo=t' => 'Ideo/Y',
    'ideo=true' => 'Ideo/Y',
    'ideo=y' => 'Ideo/Y',
    'ideo=yes' => 'Ideo/Y',
    'ideographic' => 'Ideo/Y',
    'ideographicdescriptioncharacters' => 'Blk/Ideograp',
    'ids' => 'IDS/Y',
    'ids=f' => 'IDS/N',
    'ids=false' => 'IDS/N',
    'ids=n' => 'IDS/N',
    'ids=no' => 'IDS/N',
    'ids=t' => 'IDS/Y',
    'ids=true' => 'IDS/Y',
    'ids=y' => 'IDS/Y',
    'ids=yes' => 'IDS/Y',
    'idsb' => 'IDSB/Y',
    'idsb=f' => 'IDSB/N',
    'idsb=false' => 'IDSB/N',
    'idsb=n' => 'IDSB/N',
    'idsb=no' => 'IDSB/N',
    'idsb=t' => 'IDSB/Y',
    'idsb=true' => 'IDSB/Y',
    'idsb=y' => 'IDSB/Y',
    'idsb=yes' => 'IDSB/Y',
    'idsbinaryoperator' => 'IDSB/Y',
    'idst' => 'IDST/Y',
    'idst=f' => 'IDST/N',
    'idst=false' => 'IDST/N',
    'idst=n' => 'IDST/N',
    'idst=no' => 'IDST/N',
    'idst=t' => 'IDST/Y',
    'idst=true' => 'IDST/Y',
    'idst=y' => 'IDST/Y',
    'idst=yes' => 'IDST/Y',
    'idstart' => 'IDS/Y',
    'idstrinaryoperator' => 'IDST/Y',
    'imperialaramaic' => 'Sc/Armi',
    'in=unassigned' => 'Age/Unassign',
    'inaegeannumbers' => 'Blk/AegeanNu',
    'inalphabeticpresentationforms' => 'Blk/Alphabet',
    'inancientgreekmusicalnotation' => 'Blk/Ancient2',
    'inancientgreeknumbers' => 'Blk/AncientG',
    'inancientsymbols' => 'Blk/AncientS',
    'inarabic' => 'Blk/Arabic',
    'inarabicpresentationformsa' => 'Blk/ArabicPr',
    'inarabicpresentationformsb' => 'Blk/ArabicP2',
    'inarabicsupplement' => 'Blk/ArabicSu',
    'inarmenian' => 'Blk/Armenian',
    'inarrows' => 'Blk/Arrows',
    'inascii' => 'Blk/ASCII',
    'inavestan' => 'Blk/Avestan',
    'inbalinese' => 'Blk/Balinese',
    'inbamum' => 'Blk/Bamum',
    'inbasiclatin' => 'Blk/ASCII',
    'inbengali' => 'Blk/Bengali',
    'inblockelements' => 'Blk/BlockEle',
    'inbopomofo' => 'Blk/Bopomofo',
    'inbopomofoextended' => 'Blk/Bopomof2',
    'inboxdrawing' => 'Blk/BoxDrawi',
    'inbraillepatterns' => 'Blk/BrailleP',
    'inbuginese' => 'Blk/Buginese',
    'inbuhid' => 'Blk/Buhid',
    'inbyzantinemusicalsymbols' => 'Blk/Byzantin',
    'incanadiansyllabics' => 'Blk/Canadian',
    'incarian' => 'Blk/Carian',
    'incham' => 'Blk/Cham',
    'incherokee' => 'Blk/Cherokee',
    'incjkcompatibility' => 'Blk/CJKCompa',
    'incjkcompatibilityforms' => 'Blk/CJKComp2',
    'incjkcompatibilityideographs' => 'Blk/CJKComp3',
    'incjkcompatibilityideographssupplement' => 'Blk/CJKComp4',
    'incjkradicalssupplement' => 'Blk/CJKRadic',
    'incjkstrokes' => 'Blk/CJKStrok',
    'incjksymbolsandpunctuation' => 'Blk/CJKSymbo',
    'incjkunifiedideographs' => 'Blk/CJKUnifi',
    'incjkunifiedideographsextensiona' => 'Blk/CJKUnif2',
    'incjkunifiedideographsextensionb' => 'Blk/CJKUnif3',
    'incjkunifiedideographsextensionc' => 'Blk/CJKUnif4',
    'incombiningdiacriticalmarks' => 'Blk/Combini3',
    'incombiningdiacriticalmarksforsymbols' => 'Blk/Combini2',
    'incombiningdiacriticalmarkssupplement' => 'Blk/Combini4',
    'incombininghalfmarks' => 'Blk/Combinin',
    'incombiningmarksforsymbols' => 'Blk/Combini2',
    'incommonindicnumberforms' => 'Blk/CommonIn',
    'incontrolpictures' => 'Blk/ControlP',
    'incoptic' => 'Blk/Coptic',
    'incountingrodnumerals' => 'Blk/Counting',
    'incuneiform' => 'Blk/Cuneifor',
    'incuneiformnumbersandpunctuation' => 'Blk/Cuneifo2',
    'incurrencysymbols' => 'Blk/Currency',
    'incypriotsyllabary' => 'Blk/CypriotS',
    'incyrillic' => 'Blk/Cyrillic',
    'incyrillicextendeda' => 'Blk/Cyrilli2',
    'incyrillicextendedb' => 'Blk/Cyrilli3',
    'incyrillicsupplement' => 'Blk/Cyrilli4',
    'incyrillicsupplementary' => 'Blk/Cyrilli4',
    'indeseret' => 'Blk/Deseret',
    'indevanagari' => 'Blk/Devanaga',
    'indevanagariextended' => 'Blk/Devanag2',
    'indingbats' => 'Blk/Dingbats',
    'indominotiles' => 'Blk/DominoTi',
    'inegyptianhieroglyphs' => 'Blk/Egyptian',
    'inenclosedalphanumerics' => 'Blk/Enclosed',
    'inenclosedalphanumericsupplement' => 'Blk/Enclose4',
    'inenclosedcjklettersandmonths' => 'Blk/Enclose2',
    'inenclosedideographicsupplement' => 'Blk/Enclose3',
    'inethiopic' => 'Blk/Ethiopic',
    'inethiopicextended' => 'Blk/Ethiopi2',
    'inethiopicsupplement' => 'Blk/Ethiopi3',
    'ingeneralpunctuation' => 'Blk/GeneralP',
    'ingeometricshapes' => 'Blk/Geometri',
    'ingeorgian' => 'Blk/Georgian',
    'ingeorgiansupplement' => 'Blk/Georgia2',
    'inglagolitic' => 'Blk/Glagolit',
    'ingothic' => 'Blk/Gothic',
    'ingreek' => 'Blk/Greek',
    'ingreekandcoptic' => 'Blk/Greek',
    'ingreekextended' => 'Blk/GreekExt',
    'ingujarati' => 'Blk/Gujarati',
    'ingurmukhi' => 'Blk/Gurmukhi',
    'inhalfwidthandfullwidthforms' => 'Blk/Halfwidt',
    'inhangulcompatibilityjamo' => 'Blk/HangulCo',
    'inhanguljamo' => 'Blk/HangulJa',
    'inhanguljamoextendeda' => 'Blk/HangulJ2',
    'inhanguljamoextendedb' => 'Blk/HangulJ3',
    'inhangulsyllables' => 'Blk/HangulSy',
    'inhanunoo' => 'Blk/Hanunoo',
    'inhebrew' => 'Blk/Hebrew',
    'inherited' => 'Sc/Zinh',
    'inhighprivateusesurrogates' => 'Blk/HighPriv',
    'inhighsurrogates' => 'Blk/HighSurr',
    'inhiragana' => 'Blk/Hiragana',
    'inideographicdescriptioncharacters' => 'Blk/Ideograp',
    'inimperialaramaic' => 'Blk/Imperial',
    'ininscriptionalpahlavi' => 'Blk/Inscript',
    'ininscriptionalparthian' => 'Blk/Inscrip2',
    'inipaextensions' => 'Blk/IPAExten',
    'initialpunctuation' => 'Gc/Pi',
    'injavanese' => 'Blk/Javanese',
    'inkaithi' => 'Blk/Kaithi',
    'inkanbun' => 'Blk/Kanbun',
    'inkangxiradicals' => 'Blk/KangxiRa',
    'inkannada' => 'Blk/Kannada',
    'inkatakana' => 'Blk/Katakana',
    'inkatakanaphoneticextensions' => 'Blk/Katakan2',
    'inkayahli' => 'Blk/KayahLi',
    'inkharoshthi' => 'Blk/Kharosht',
    'inkhmer' => 'Blk/Khmer',
    'inkhmersymbols' => 'Blk/KhmerSym',
    'inlao' => 'Blk/Lao',
    'inlatin1' => 'Blk/Latin1',
    'inlatin1supplement' => 'Blk/Latin1',
    'inlatinextendeda' => 'Blk/LatinExt',
    'inlatinextendedadditional' => 'Blk/LatinEx5',
    'inlatinextendedb' => 'Blk/LatinEx2',
    'inlatinextendedc' => 'Blk/LatinEx3',
    'inlatinextendedd' => 'Blk/LatinEx4',
    'inlepcha' => 'Blk/Lepcha',
    'inletterlikesymbols' => 'Blk/Letterli',
    'inlimbu' => 'Blk/Limbu',
    'inlinearbideograms' => 'Blk/LinearBI',
    'inlinearbsyllabary' => 'Blk/LinearBS',
    'inlisu' => 'Blk/Lisu',
    'inlowsurrogates' => 'Blk/LowSurro',
    'inlycian' => 'Blk/Lycian',
    'inlydian' => 'Blk/Lydian',
    'inmahjongtiles' => 'Blk/MahjongT',
    'inmalayalam' => 'Blk/Malayala',
    'inmathematicalalphanumericsymbols' => 'Blk/Mathema2',
    'inmathematicaloperators' => 'Blk/Mathemat',
    'inmeeteimayek' => 'Blk/MeeteiMa',
    'inmiscellaneousmathematicalsymbolsa' => 'Blk/Miscell4',
    'inmiscellaneousmathematicalsymbolsb' => 'Blk/Miscell5',
    'inmiscellaneoussymbols' => 'Blk/Miscella',
    'inmiscellaneoussymbolsandarrows' => 'Blk/Miscell3',
    'inmiscellaneoustechnical' => 'Blk/Miscell2',
    'inmodifiertoneletters' => 'Blk/Modifier',
    'inmongolian' => 'Blk/Mongolia',
    'inmusicalsymbols' => 'Blk/MusicalS',
    'inmyanmar' => 'Blk/Myanmar',
    'inmyanmarextendeda' => 'Blk/MyanmarE',
    'innewtailue' => 'Blk/NewTaiLu',
    'innko' => 'Blk/NKo',
    'innoblock' => 'Blk/NoBlock',
    'innumberforms' => 'Blk/NumberFo',
    'inogham' => 'Blk/Ogham',
    'inolchiki' => 'Blk/OlChiki',
    'inolditalic' => 'Blk/OldItali',
    'inoldpersian' => 'Blk/OldPersi',
    'inoldsoutharabian' => 'Blk/OldSouth',
    'inoldturkic' => 'Blk/OldTurki',
    'inopticalcharacterrecognition' => 'Blk/OpticalC',
    'inoriya' => 'Blk/Oriya',
    'inosmanya' => 'Blk/Osmanya',
    'inphagspa' => 'Blk/PhagsPa',
    'inphaistosdisc' => 'Blk/Phaistos',
    'inphoenician' => 'Blk/Phoenici',
    'inphoneticextensions' => 'Blk/Phonetic',
    'inphoneticextensionssupplement' => 'Blk/Phoneti2',
    'inprivateuse' => 'Blk/PrivateU',
    'inprivateusearea' => 'Blk/PrivateU',
    'inrejang' => 'Blk/Rejang',
    'inruminumeralsymbols' => 'Blk/RumiNume',
    'inrunic' => 'Blk/Runic',
    'insamaritan' => 'Blk/Samarita',
    'insaurashtra' => 'Blk/Saurasht',
    'inscriptionalpahlavi' => 'Sc/Phli',
    'inscriptionalparthian' => 'Sc/Prti',
    'inshavian' => 'Blk/Shavian',
    'insinhala' => 'Blk/Sinhala',
    'insmallformvariants' => 'Blk/SmallFor',
    'inspacingmodifierletters' => 'Blk/SpacingM',
    'inspecials' => 'Blk/Specials',
    'insundanese' => 'Blk/Sundanes',
    'insuperscriptsandsubscripts' => 'Blk/Superscr',
    'insupplementalarrowsa' => 'Blk/Suppleme',
    'insupplementalarrowsb' => 'Blk/Supplem2',
    'insupplementalmathematicaloperators' => 'Blk/Supplem6',
    'insupplementalpunctuation' => 'Blk/Supplem3',
    'insupplementaryprivateuseareaa' => 'Blk/Supplem4',
    'insupplementaryprivateuseareab' => 'Blk/Supplem5',
    'insylotinagri' => 'Blk/SylotiNa',
    'insyriac' => 'Blk/Syriac',
    'intagalog' => 'Blk/Tagalog',
    'intagbanwa' => 'Blk/Tagbanwa',
    'intags' => 'Blk/Tags',
    'intaile' => 'Blk/TaiLe',
    'intaitham' => 'Blk/TaiTham',
    'intaiviet' => 'Blk/TaiViet',
    'intaixuanjingsymbols' => 'Blk/TaiXuanJ',
    'intamil' => 'Blk/Tamil',
    'intelugu' => 'Blk/Telugu',
    'inthaana' => 'Blk/Thaana',
    'inthai' => 'Blk/Thai',
    'intibetan' => 'Blk/Tibetan',
    'intifinagh' => 'Blk/Tifinagh',
    'inugaritic' => 'Blk/Ugaritic',
    'inunifiedcanadianaboriginalsyllabics' => 'Blk/Canadian',
    'inunifiedcanadianaboriginalsyllabicsextended' => 'Blk/UnifiedC',
    'invai' => 'Blk/Vai',
    'invariationselectors' => 'Blk/Variatio',
    'invariationselectorssupplement' => 'Blk/Variati2',
    'invedicextensions' => 'Blk/VedicExt',
    'inverticalforms' => 'Blk/Vertical',
    'inyijinghexagramsymbols' => 'Blk/YijingHe',
    'inyiradicals' => 'Blk/YiRadica',
    'inyisyllables' => 'Blk/YiSyllab',
    'ipaextensions' => 'Blk/IPAExten',
    'isaegeannumbers' => 'Blk/AegeanNu',
    'isahex' => 'AHex/Y',
    'isall' => 'Perl/Any',
    'isalnum' => 'Perl/Alnum',
    'isalpha' => 'Alpha/Y',
    'isalphabetic' => 'Alpha/Y',
    'isalphabeticpresentationforms' => 'Blk/Alphabet',
    'isancientgreekmusicalnotation' => 'Blk/Ancient2',
    'isancientgreeknumbers' => 'Blk/AncientG',
    'isancientsymbols' => 'Blk/AncientS',
    'isany' => 'Perl/Any',
    'isarab' => 'Sc/Arab',
    'isarabic' => 'Sc/Arab',
    'isarabicpresentationformsa' => 'Blk/ArabicPr',
    'isarabicpresentationformsb' => 'Blk/ArabicP2',
    'isarabicsupplement' => 'Blk/ArabicSu',
    'isarmenian' => 'Sc/Armn',
    'isarmi' => 'Sc/Armi',
    'isarmn' => 'Sc/Armn',
    'isarrows' => 'Blk/Arrows',
    'isascii' => 'Blk/ASCII',
    'isasciihexdigit' => 'AHex/Y',
    'isassigned' => 'Perl/Assigned',
    'isavestan' => 'Sc/Avst',
    'isavst' => 'Sc/Avst',
    'isbali' => 'Sc/Bali',
    'isbalinese' => 'Sc/Bali',
    'isbamu' => 'Sc/Bamu',
    'isbamum' => 'Sc/Bamu',
    'isbasiclatin' => 'Blk/ASCII',
    'isbeng' => 'Sc/Beng',
    'isbengali' => 'Sc/Beng',
    'isbidic' => 'BidiC/Y',
    'isbidicontrol' => 'BidiC/Y',
    'isbidim' => 'BidiM/Y',
    'isbidimirrored' => 'BidiM/Y',
    'isblank' => 'Perl/Blank',
    'isblockelements' => 'Blk/BlockEle',
    'isbopo' => 'Sc/Bopo',
    'isbopomofo' => 'Sc/Bopo',
    'isbopomofoextended' => 'Blk/Bopomof2',
    'isboxdrawing' => 'Blk/BoxDrawi',
    'isbrai' => 'Blk/BrailleP',
    'isbraille' => 'Blk/BrailleP',
    'isbraillepatterns' => 'Blk/BrailleP',
    'isbugi' => 'Sc/Bugi',
    'isbuginese' => 'Sc/Bugi',
    'isbuhd' => 'Sc/Buhd',
    'isbuhid' => 'Sc/Buhd',
    'isbyzantinemusicalsymbols' => 'Blk/Byzantin',
    'isc' => 'Gc/C',
    'iscanadianaboriginal' => 'Sc/Cans',
    'iscanadiansyllabics' => 'Blk/Canadian',
    'iscans' => 'Sc/Cans',
    'iscari' => 'Sc/Cari',
    'iscarian' => 'Sc/Cari',
    'iscased' => 'Cased/Y',
    'iscasedletter' => 'Gc/LC',
    'iscaseignorable' => 'CI/Y',
    'iscc' => 'Gc/Cc',
    'isce' => 'CE/Y',
    'iscf' => 'Gc/Cf',
    'ischam' => 'Sc/Cham',
    'ischangeswhencasefolded' => 'CWCF/Y',
    'ischangeswhencasemapped' => 'CWCM/Y',
    'ischangeswhenlowercased' => 'CWL/Y',
    'ischangeswhennfkccasefolded' => 'CWKCF/Y',
    'ischangeswhentitlecased' => 'CWT/Y',
    'ischangeswhenuppercased' => 'CWU/Y',
    'ischer' => 'Sc/Cher',
    'ischerokee' => 'Sc/Cher',
    'isci' => 'CI/Y',
    'iscjkcompatibility' => 'Blk/CJKCompa',
    'iscjkcompatibilityforms' => 'Blk/CJKComp2',
    'iscjkcompatibilityideographs' => 'Blk/CJKComp3',
    'iscjkcompatibilityideographssupplement' => 'Blk/CJKComp4',
    'iscjkradicalssupplement' => 'Blk/CJKRadic',
    'iscjkstrokes' => 'Blk/CJKStrok',
    'iscjksymbolsandpunctuation' => 'Blk/CJKSymbo',
    'iscjkunifiedideographs' => 'Blk/CJKUnifi',
    'iscjkunifiedideographsextensiona' => 'Blk/CJKUnif2',
    'iscjkunifiedideographsextensionb' => 'Blk/CJKUnif3',
    'iscjkunifiedideographsextensionc' => 'Blk/CJKUnif4',
    'isclosepunctuation' => 'Gc/Pe',
    'iscn' => 'Gc/Cn',
    'iscntrl' => 'Gc/Cc',
    'isco' => 'Gc/Co',
    'iscombiningdiacriticalmarks' => 'Blk/Combini3',
    'iscombiningdiacriticalmarksforsymbols' => 'Blk/Combini2',
    'iscombiningdiacriticalmarkssupplement' => 'Blk/Combini4',
    'iscombininghalfmarks' => 'Blk/Combinin',
    'iscombiningmarksforsymbols' => 'Blk/Combini2',
    'iscommon' => 'Sc/Zyyy',
    'iscommonindicnumberforms' => 'Blk/CommonIn',
    'iscompex' => 'CompEx/Y',
    'iscompositionexclusion' => 'CE/Y',
    'isconnectorpunctuation' => 'WB/EX',
    'iscontrol' => 'Gc/Cc',
    'iscontrolpictures' => 'Blk/ControlP',
    'iscopt' => 'Sc/Copt',
    'iscoptic' => 'Sc/Copt',
    'iscountingrodnumerals' => 'Blk/Counting',
    'iscprt' => 'Sc/Cprt',
    'iscs' => 'Gc/Cs',
    'iscuneiform' => 'Sc/Xsux',
    'iscuneiformnumbersandpunctuation' => 'Blk/Cuneifo2',
    'iscurrencysymbol' => 'Gc/Sc',
    'iscurrencysymbols' => 'Blk/Currency',
    'iscwcf' => 'CWCF/Y',
    'iscwcm' => 'CWCM/Y',
    'iscwkcf' => 'CWKCF/Y',
    'iscwl' => 'CWL/Y',
    'iscwt' => 'CWT/Y',
    'iscwu' => 'CWU/Y',
    'iscypriot' => 'Sc/Cprt',
    'iscypriotsyllabary' => 'Blk/CypriotS',
    'iscyrillic' => 'Sc/Cyrl',
    'iscyrillicextendeda' => 'Blk/Cyrilli2',
    'iscyrillicextendedb' => 'Blk/Cyrilli3',
    'iscyrillicsupplement' => 'Blk/Cyrilli4',
    'iscyrillicsupplementary' => 'Blk/Cyrilli4',
    'iscyrl' => 'Sc/Cyrl',
    'isdash' => 'Dash/Y',
    'isdashpunctuation' => 'Gc/Pd',
    'isdecimalnumber' => 'Nt/De',
    'isdefaultignorablecodepoint' => 'DI/Y',
    'isdep' => 'Dep/Y',
    'isdeprecated' => 'Dep/Y',
    'isdeseret' => 'Blk/Deseret',
    'isdeva' => 'Sc/Deva',
    'isdevanagari' => 'Sc/Deva',
    'isdevanagariextended' => 'Blk/Devanag2',
    'isdi' => 'DI/Y',
    'isdia' => 'Dia/Y',
    'isdiacritic' => 'Dia/Y',
    'isdigit' => 'Nt/De',
    'isdingbats' => 'Blk/Dingbats',
    'isdominotiles' => 'Blk/DominoTi',
    'isdsrt' => 'Blk/Deseret',
    'isegyp' => 'Sc/Egyp',
    'isegyptianhieroglyphs' => 'Sc/Egyp',
    'isenclosedalphanumerics' => 'Blk/Enclosed',
    'isenclosedalphanumericsupplement' => 'Blk/Enclose4',
    'isenclosedcjklettersandmonths' => 'Blk/Enclose2',
    'isenclosedideographicsupplement' => 'Blk/Enclose3',
    'isenclosingmark' => 'Gc/Me',
    'isethi' => 'Sc/Ethi',
    'isethiopic' => 'Sc/Ethi',
    'isethiopicextended' => 'Blk/Ethiopi2',
    'isethiopicsupplement' => 'Blk/Ethiopi3',
    'isext' => 'Ext/Y',
    'isextender' => 'Ext/Y',
    'isfinalpunctuation' => 'Gc/Pf',
    'isformat' => 'Gc/Cf',
    'isfullcompositionexclusion' => 'CompEx/Y',
    'isgeneralpunctuation' => 'Blk/GeneralP',
    'isgeometricshapes' => 'Blk/Geometri',
    'isgeor' => 'Sc/Geor',
    'isgeorgian' => 'Sc/Geor',
    'isgeorgiansupplement' => 'Blk/Georgia2',
    'isglag' => 'Sc/Glag',
    'isglagolitic' => 'Sc/Glag',
    'isgoth' => 'Sc/Goth',
    'isgothic' => 'Sc/Goth',
    'isgraph' => 'Perl/Graph',
    'isgraphemebase' => 'GrBase/Y',
    'isgraphemeextend' => 'GrExt/Y',
    'isgrbase' => 'GrBase/Y',
    'isgreek' => 'Sc/Grek',
    'isgreekandcoptic' => 'Blk/Greek',
    'isgreekextended' => 'Blk/GreekExt',
    'isgrek' => 'Sc/Grek',
    'isgrext' => 'GrExt/Y',
    'isgujarati' => 'Sc/Gujr',
    'isgujr' => 'Sc/Gujr',
    'isgurmukhi' => 'Sc/Guru',
    'isguru' => 'Sc/Guru',
    'ishalfwidthandfullwidthforms' => 'Blk/Halfwidt',
    'ishan' => 'Sc/Han',
    'ishang' => 'Sc/Hang',
    'ishangul' => 'Sc/Hang',
    'ishangulcompatibilityjamo' => 'Blk/HangulCo',
    'ishanguljamo' => 'Blk/HangulJa',
    'ishanguljamoextendeda' => 'Blk/HangulJ2',
    'ishanguljamoextendedb' => 'Blk/HangulJ3',
    'ishangulsyllables' => 'Blk/HangulSy',
    'ishani' => 'Sc/Han',
    'ishano' => 'Sc/Hano',
    'ishanunoo' => 'Sc/Hano',
    'ishebr' => 'Sc/Hebr',
    'ishebrew' => 'Sc/Hebr',
    'ishex' => 'Hex/Y',
    'ishexdigit' => 'Hex/Y',
    'ishighprivateusesurrogates' => 'Blk/HighPriv',
    'ishighsurrogates' => 'Blk/HighSurr',
    'ishira' => 'Sc/Hira',
    'ishiragana' => 'Sc/Hira',
    'ishorizspace' => 'Perl/Blank',
    'ishyphen' => 'Hyphen/Y',
    'isidc' => 'IDC/Y',
    'isidcontinue' => 'IDC/Y',
    'isideo' => 'Ideo/Y',
    'isideographic' => 'Ideo/Y',
    'isideographicdescriptioncharacters' => 'Blk/Ideograp',
    'isids' => 'IDS/Y',
    'isidsb' => 'IDSB/Y',
    'isidsbinaryoperator' => 'IDSB/Y',
    'isidst' => 'IDST/Y',
    'isidstart' => 'IDS/Y',
    'isidstrinaryoperator' => 'IDST/Y',
    'isimperialaramaic' => 'Sc/Armi',
    'isinherited' => 'Sc/Zinh',
    'isinitialpunctuation' => 'Gc/Pi',
    'isinscriptionalpahlavi' => 'Sc/Phli',
    'isinscriptionalparthian' => 'Sc/Prti',
    'isipaextensions' => 'Blk/IPAExten',
    'isital' => 'Sc/Ital',
    'isjava' => 'Sc/Java',
    'isjavanese' => 'Sc/Java',
    'isjoinc' => 'JoinC/Y',
    'isjoincontrol' => 'JoinC/Y',
    'iskaithi' => 'Sc/Kthi',
    'iskali' => 'Blk/KayahLi',
    'iskana' => 'Sc/Kana',
    'iskanbun' => 'Blk/Kanbun',
    'iskangxiradicals' => 'Blk/KangxiRa',
    'iskannada' => 'Sc/Knda',
    'iskatakana' => 'Sc/Kana',
    'iskatakanaphoneticextensions' => 'Blk/Katakan2',
    'iskayahli' => 'Blk/KayahLi',
    'iskhar' => 'Sc/Khar',
    'iskharoshthi' => 'Sc/Khar',
    'iskhmer' => 'Sc/Khmr',
    'iskhmersymbols' => 'Blk/KhmerSym',
    'iskhmr' => 'Sc/Khmr',
    'isknda' => 'Sc/Knda',
    'iskthi' => 'Sc/Kthi',
    'isl' => 'Gc/L',
    'isl&' => 'Gc/LC',
    'isl_' => 'Gc/LC',
    'islana' => 'Sc/Lana',
    'islao' => 'Sc/Lao',
    'islaoo' => 'Sc/Lao',
    'islatin' => 'Sc/Latn',
    'islatin1' => 'Blk/Latin1',
    'islatin1supplement' => 'Blk/Latin1',
    'islatinextendeda' => 'Blk/LatinExt',
    'islatinextendedadditional' => 'Blk/LatinEx5',
    'islatinextendedb' => 'Blk/LatinEx2',
    'islatinextendedc' => 'Blk/LatinEx3',
    'islatinextendedd' => 'Blk/LatinEx4',
    'islatn' => 'Sc/Latn',
    'islc' => 'Gc/LC',
    'islepc' => 'Sc/Lepc',
    'islepcha' => 'Sc/Lepc',
    'isletter' => 'Gc/L',
    'isletterlikesymbols' => 'Blk/Letterli',
    'isletternumber' => 'Gc/Nl',
    'islimb' => 'Sc/Limb',
    'islimbu' => 'Sc/Limb',
    'islinb' => 'Sc/Linb',
    'islinearb' => 'Sc/Linb',
    'islinearbideograms' => 'Blk/LinearBI',
    'islinearbsyllabary' => 'Blk/LinearBS',
    'islineseparator' => 'Gc/Zl',
    'islisu' => 'Blk/Lisu',
    'isll' => 'Gc/Ll',
    'islm' => 'Gc/Lm',
    'islo' => 'Gc/Lo',
    'isloe' => 'GCB/PP',
    'islogicalorderexception' => 'GCB/PP',
    'islower' => 'Lower/Y',
    'islowercase' => 'Lower/Y',
    'islowercaseletter' => 'Gc/Ll',
    'islowsurrogates' => 'Blk/LowSurro',
    'islt' => 'Gc/Lt',
    'islu' => 'Gc/Lu',
    'islyci' => 'Sc/Lyci',
    'islycian' => 'Sc/Lyci',
    'islydi' => 'Sc/Lydi',
    'islydian' => 'Sc/Lydi',
    'ism' => 'Gc/M',
    'ismahjongtiles' => 'Blk/MahjongT',
    'ismalayalam' => 'Sc/Mlym',
    'ismark' => 'Gc/M',
    'ismath' => 'Math/Y',
    'ismathematicalalphanumericsymbols' => 'Blk/Mathema2',
    'ismathematicaloperators' => 'Blk/Mathemat',
    'ismathsymbol' => 'Gc/Sm',
    'ismc' => 'Gc/Mc',
    'isme' => 'Gc/Me',
    'ismeeteimayek' => 'Sc/Mtei',
    'ismiscellaneousmathematicalsymbolsa' => 'Blk/Miscell4',
    'ismiscellaneousmathematicalsymbolsb' => 'Blk/Miscell5',
    'ismiscellaneoussymbols' => 'Blk/Miscella',
    'ismiscellaneoussymbolsandarrows' => 'Blk/Miscell3',
    'ismiscellaneoustechnical' => 'Blk/Miscell2',
    'ismlym' => 'Sc/Mlym',
    'ismn' => 'Gc/Mn',
    'ismodifierletter' => 'Gc/Lm',
    'ismodifiersymbol' => 'Gc/Sk',
    'ismodifiertoneletters' => 'Blk/Modifier',
    'ismong' => 'Sc/Mong',
    'ismongolian' => 'Sc/Mong',
    'ismtei' => 'Sc/Mtei',
    'ismusicalsymbols' => 'Blk/MusicalS',
    'ismyanmar' => 'Sc/Mymr',
    'ismyanmarextendeda' => 'Blk/MyanmarE',
    'ismymr' => 'Sc/Mymr',
    'isn' => 'Gc/N',
    'isnchar' => 'NChar/Y',
    'isnd' => 'Nt/De',
    'isnewtailue' => 'Sc/Talu',
    'isnko' => 'Sc/Nko',
    'isnkoo' => 'Sc/Nko',
    'isnl' => 'Gc/Nl',
    'isno' => 'Gc/No',
    'isnoblock' => 'Blk/NoBlock',
    'isnoncharactercodepoint' => 'NChar/Y',
    'isnonspacingmark' => 'Gc/Mn',
    'isnumber' => 'Gc/N',
    'isnumberforms' => 'Blk/NumberFo',
    'isoalpha' => 'OAlpha/Y',
    'isodi' => 'ODI/Y',
    'isogam' => 'Sc/Ogam',
    'isogham' => 'Sc/Ogam',
    'isogrext' => 'OGrExt/Y',
    'isoidc' => 'OIDC/Y',
    'isoids' => 'OIDS/Y',
    'isolchiki' => 'Blk/OlChiki',
    'isolck' => 'Blk/OlChiki',
    'isolditalic' => 'Sc/Ital',
    'isoldpersian' => 'Sc/Xpeo',
    'isoldsoutharabian' => 'Blk/OldSouth',
    'isoldturkic' => 'Sc/Orkh',
    'isolower' => 'OLower/Y',
    'isomath' => 'OMath/Y',
    'isopenpunctuation' => 'Gc/Ps',
    'isopticalcharacterrecognition' => 'Blk/OpticalC',
    'isoriya' => 'Sc/Orya',
    'isorkh' => 'Sc/Orkh',
    'isorya' => 'Sc/Orya',
    'isosma' => 'Sc/Osma',
    'isosmanya' => 'Sc/Osma',
    'isother' => 'Gc/C',
    'isotheralphabetic' => 'OAlpha/Y',
    'isotherdefaultignorablecodepoint' => 'ODI/Y',
    'isothergraphemeextend' => 'OGrExt/Y',
    'isotheridcontinue' => 'OIDC/Y',
    'isotheridstart' => 'OIDS/Y',
    'isotherletter' => 'Gc/Lo',
    'isotherlowercase' => 'OLower/Y',
    'isothermath' => 'OMath/Y',
    'isothernumber' => 'Gc/No',
    'isotherpunctuation' => 'Gc/Po',
    'isothersymbol' => 'Gc/So',
    'isotheruppercase' => 'OUpper/Y',
    'isoupper' => 'OUpper/Y',
    'isp' => 'Gc/P',
    'isparagraphseparator' => 'Gc/Zp',
    'ispatsyn' => 'PatSyn/Y',
    'ispatternsyntax' => 'PatSyn/Y',
    'ispatternwhitespace' => 'PatWS/Y',
    'ispatws' => 'PatWS/Y',
    'ispc' => 'WB/EX',
    'ispd' => 'Gc/Pd',
    'ispe' => 'Gc/Pe',
    'isperlspace' => 'Perl/PerlSpac',
    'isperlword' => 'Perl/PerlWord',
    'ispf' => 'Gc/Pf',
    'isphag' => 'Sc/Phag',
    'isphagspa' => 'Sc/Phag',
    'isphaistosdisc' => 'Blk/Phaistos',
    'isphli' => 'Sc/Phli',
    'isphnx' => 'Sc/Phnx',
    'isphoenician' => 'Sc/Phnx',
    'isphoneticextensions' => 'Blk/Phonetic',
    'isphoneticextensionssupplement' => 'Blk/Phoneti2',
    'ispi' => 'Gc/Pi',
    'ispo' => 'Gc/Po',
    'isposixalnum' => 'Perl/PosixAln',
    'isposixalpha' => 'Perl/PosixAlp',
    'isposixblank' => 'Perl/PosixBla',
    'isposixcntrl' => 'Perl/PosixCnt',
    'isposixdigit' => 'Perl/PosixDig',
    'isposixgraph' => 'Perl/PosixGra',
    'isposixlower' => 'Perl/PosixLow',
    'isposixprint' => 'Perl/PosixPri',
    'isposixpunct' => 'Perl/PosixPun',
    'isposixspace' => 'Perl/PosixSpa',
    'isposixupper' => 'Perl/PosixUpp',
    'isprint' => 'Perl/Print',
    'isprivateuse' => 'Gc/Co',
    'isprivateusearea' => 'Blk/PrivateU',
    'isprti' => 'Sc/Prti',
    'isps' => 'Gc/Ps',
    'ispunct' => 'Gc/P',
    'ispunctuation' => 'Gc/P',
    'isqaac' => 'Sc/Copt',
    'isqaai' => 'Sc/Zinh',
    'isqmark' => 'QMark/Y',
    'isquotationmark' => 'QMark/Y',
    'isradical' => 'Radical/Y',
    'isrejang' => 'Sc/Rjng',
    'isrjng' => 'Sc/Rjng',
    'isruminumeralsymbols' => 'Blk/RumiNume',
    'isrunic' => 'Sc/Runr',
    'isrunr' => 'Sc/Runr',
    'iss' => 'Gc/S',
    'issamaritan' => 'Sc/Samr',
    'issamr' => 'Sc/Samr',
    'issarb' => 'Blk/OldSouth',
    'issaur' => 'Sc/Saur',
    'issaurashtra' => 'Sc/Saur',
    'issc' => 'Gc/Sc',
    'issd' => 'SD/Y',
    'isseparator' => 'Gc/Z',
    'isshavian' => 'Blk/Shavian',
    'isshaw' => 'Blk/Shavian',
    'issinh' => 'Sc/Sinh',
    'issinhala' => 'Sc/Sinh',
    'issk' => 'Gc/Sk',
    'issm' => 'Gc/Sm',
    'issmallformvariants' => 'Blk/SmallFor',
    'isso' => 'Gc/So',
    'issoftdotted' => 'SD/Y',
    'isspace' => 'Space/Y',
    'isspaceperl' => 'Perl/SpacePer',
    'isspaceseparator' => 'Gc/Zs',
    'isspacingmark' => 'Gc/Mc',
    'isspacingmodifierletters' => 'Blk/SpacingM',
    'isspecials' => 'Blk/Specials',
    'issterm' => 'STerm/Y',
    'issund' => 'Sc/Sund',
    'issundanese' => 'Sc/Sund',
    'issuperscriptsandsubscripts' => 'Blk/Superscr',
    'issupplementalarrowsa' => 'Blk/Suppleme',
    'issupplementalarrowsb' => 'Blk/Supplem2',
    'issupplementalmathematicaloperators' => 'Blk/Supplem6',
    'issupplementalpunctuation' => 'Blk/Supplem3',
    'issupplementaryprivateuseareaa' => 'Blk/Supplem4',
    'issupplementaryprivateuseareab' => 'Blk/Supplem5',
    'issurrogate' => 'Gc/Cs',
    'issylo' => 'Sc/Sylo',
    'issylotinagri' => 'Sc/Sylo',
    'issymbol' => 'Gc/S',
    'issyrc' => 'Sc/Syrc',
    'issyriac' => 'Sc/Syrc',
    'istagalog' => 'Sc/Tglg',
    'istagb' => 'Sc/Tagb',
    'istagbanwa' => 'Sc/Tagb',
    'istags' => 'Blk/Tags',
    'istaile' => 'Sc/Tale',
    'istaitham' => 'Sc/Lana',
    'istaiviet' => 'Sc/Tavt',
    'istaixuanjingsymbols' => 'Blk/TaiXuanJ',
    'istale' => 'Sc/Tale',
    'istalu' => 'Sc/Talu',
    'istamil' => 'Sc/Taml',
    'istaml' => 'Sc/Taml',
    'istavt' => 'Sc/Tavt',
    'istelu' => 'Sc/Telu',
    'istelugu' => 'Sc/Telu',
    'isterm' => 'Term/Y',
    'isterminalpunctuation' => 'Term/Y',
    'istfng' => 'Sc/Tfng',
    'istglg' => 'Sc/Tglg',
    'isthaa' => 'Sc/Thaa',
    'isthaana' => 'Sc/Thaa',
    'isthai' => 'Sc/Thai',
    'istibetan' => 'Sc/Tibt',
    'istibt' => 'Sc/Tibt',
    'istifinagh' => 'Sc/Tfng',
    'istitle' => 'Gc/Lt',
    'istitlecaseletter' => 'Gc/Lt',
    'isugar' => 'Sc/Ugar',
    'isugaritic' => 'Sc/Ugar',
    'isuideo' => 'UIdeo/Y',
    'isunassigned' => 'Gc/Cn',
    'isunifiedcanadianaboriginalsyllabics' => 'Blk/Canadian',
    'isunifiedcanadianaboriginalsyllabicsextended' => 'Blk/UnifiedC',
    'isunifiedideograph' => 'UIdeo/Y',
    'isunknown' => 'Sc/Zzzz',
    'isupper' => 'Upper/Y',
    'isuppercase' => 'Upper/Y',
    'isuppercaseletter' => 'Gc/Lu',
    'isvai' => 'Sc/Vai',
    'isvaii' => 'Sc/Vai',
    'isvariationselector' => 'VS/Y',
    'isvariationselectors' => 'Blk/Variatio',
    'isvariationselectorssupplement' => 'Blk/Variati2',
    'isvedicextensions' => 'Blk/VedicExt',
    'isverticalforms' => 'Blk/Vertical',
    'isvertspace' => 'Perl/VertSpac',
    'isvs' => 'VS/Y',
    'iswhitespace' => 'Space/Y',
    'isword' => 'Perl/Word',
    'iswspace' => 'Space/Y',
    'isxdigit' => 'Hex/Y',
    'isxidc' => 'XIDC/Y',
    'isxidcontinue' => 'XIDC/Y',
    'isxids' => 'XIDS/Y',
    'isxidstart' => 'XIDS/Y',
    'isxpeo' => 'Sc/Xpeo',
    'isxsux' => 'Sc/Xsux',
    'isyi' => 'Sc/Yi',
    'isyiii' => 'Sc/Yi',
    'isyijinghexagramsymbols' => 'Blk/YijingHe',
    'isyiradicals' => 'Blk/YiRadica',
    'isyisyllables' => 'Blk/YiSyllab',
    'isz' => 'Gc/Z',
    'iszinh' => 'Sc/Zinh',
    'iszl' => 'Gc/Zl',
    'iszp' => 'Gc/Zp',
    'iszs' => 'Gc/Zs',
    'iszyyy' => 'Sc/Zyyy',
    'iszzzz' => 'Sc/Zzzz',
    'ital' => 'Sc/Ital',
    'java' => 'Sc/Java',
    'javanese' => 'Sc/Java',
    'jg=ain' => 'Jg/Ain',
    'jg=alaph' => 'Jg/Alaph',
    'jg=alef' => 'Jg/Alef',
    'jg=beh' => 'Jg/Beh',
    'jg=beth' => 'Jg/Beth',
    'jg=burushaskiyehbarree' => 'Jg/Burushas',
    'jg=dal' => 'Jg/Dal',
    'jg=dalathrish' => 'Jg/DalathRi',
    'jg=e' => 'Jg/E',
    'jg=farsiyeh' => 'Jg/FarsiYeh',
    'jg=fe' => 'Jg/Fe',
    'jg=feh' => 'Jg/Feh',
    'jg=finalsemkath' => 'Jg/FinalSem',
    'jg=gaf' => 'Jg/Gaf',
    'jg=gamal' => 'Jg/Gamal',
    'jg=hah' => 'Jg/Hah',
    'jg=hamzaonhehgoal' => 'Jg/HamzaOnH',
    'jg=he' => 'Jg/He',
    'jg=heh' => 'Jg/Heh',
    'jg=hehgoal' => 'Jg/HehGoal',
    'jg=heth' => 'Jg/Heth',
    'jg=kaf' => 'Jg/Kaf',
    'jg=kaph' => 'Jg/Kaph',
    'jg=khaph' => 'Jg/Khaph',
    'jg=knottedheh' => 'Jg/KnottedH',
    'jg=lam' => 'Jg/Lam',
    'jg=lamadh' => 'Jg/Lamadh',
    'jg=meem' => 'Jg/Meem',
    'jg=mim' => 'Jg/Mim',
    'jg=nojoininggroup' => 'Jg/NoJoinin',
    'jg=noon' => 'Jg/Noon',
    'jg=nun' => 'Jg/Nun',
    'jg=nya' => 'Jg/Nya',
    'jg=pe' => 'Jg/Pe',
    'jg=qaf' => 'Jg/Qaf',
    'jg=qaph' => 'Jg/Qaph',
    'jg=reh' => 'Jg/Reh',
    'jg=reversedpe' => 'Jg/Reversed',
    'jg=sad' => 'Jg/Sad',
    'jg=sadhe' => 'Jg/Sadhe',
    'jg=seen' => 'Jg/Seen',
    'jg=semkath' => 'Jg/Semkath',
    'jg=shin' => 'Jg/Shin',
    'jg=swashkaf' => 'Jg/SwashKaf',
    'jg=syriacwaw' => 'Jg/SyriacWa',
    'jg=tah' => 'Jg/Tah',
    'jg=taw' => 'Jg/Taw',
    'jg=tehmarbuta' => 'Jg/TehMarbu',
    'jg=teth' => 'Jg/Teth',
    'jg=waw' => 'Jg/Waw',
    'jg=yeh' => 'Jg/Yeh',
    'jg=yehbarree' => 'Jg/YehBarre',
    'jg=yehwithtail' => 'Jg/YehWithT',
    'jg=yudh' => 'Jg/Yudh',
    'jg=yudhhe' => 'Jg/YudhHe',
    'jg=zain' => 'Jg/Zain',
    'jg=zhain' => 'Jg/Zhain',
    'joinc' => 'JoinC/Y',
    'joinc=f' => 'JoinC/N',
    'joinc=false' => 'JoinC/N',
    'joinc=n' => 'JoinC/N',
    'joinc=no' => 'JoinC/N',
    'joinc=t' => 'JoinC/Y',
    'joinc=true' => 'JoinC/Y',
    'joinc=y' => 'JoinC/Y',
    'joinc=yes' => 'JoinC/Y',
    'joincontrol' => 'JoinC/Y',
    'jt=c' => 'Jt/C',
    'jt=d' => 'Jt/D',
    'jt=dualjoining' => 'Jt/D',
    'jt=joincausing' => 'Jt/C',
    'jt=l' => 'Ccc/ATBL',
    'jt=leftjoining' => 'Ccc/ATBL',
    'jt=nonjoining' => 'Jt/U',
    'jt=r' => 'Jt/R',
    'jt=rightjoining' => 'Jt/R',
    'jt=t' => 'Jt/T',
    'jt=transparent' => 'Jt/T',
    'jt=u' => 'Jt/U',
    'kaithi' => 'Sc/Kthi',
    'kali' => 'Blk/KayahLi',
    'kana' => 'Sc/Kana',
    'kanbun' => 'Blk/Kanbun',
    'kangxiradicals' => 'Blk/KangxiRa',
    'kannada' => 'Sc/Knda',
    'katakana' => 'Sc/Kana',
    'katakanaphoneticextensions' => 'Blk/Katakan2',
    'kayahli' => 'Blk/KayahLi',
    'khar' => 'Sc/Khar',
    'kharoshthi' => 'Sc/Khar',
    'khmer' => 'Sc/Khmr',
    'khmersymbols' => 'Blk/KhmerSym',
    'khmr' => 'Sc/Khmr',
    'knda' => 'Sc/Knda',
    'kthi' => 'Sc/Kthi',
    'l' => 'Gc/L',
    'l&' => 'Gc/LC',
    'l_' => 'Gc/LC',
    'lana' => 'Sc/Lana',
    'lao' => 'Sc/Lao',
    'laoo' => 'Sc/Lao',
    'latin' => 'Sc/Latn',
    'latin1' => 'Blk/Latin1',
    'latin1supplement' => 'Blk/Latin1',
    'latinextendeda' => 'Blk/LatinExt',
    'latinextendedadditional' => 'Blk/LatinEx5',
    'latinextendedb' => 'Blk/LatinEx2',
    'latinextendedc' => 'Blk/LatinEx3',
    'latinextendedd' => 'Blk/LatinEx4',
    'latn' => 'Sc/Latn',
    'lb=ai' => 'Lb/AI',
    'lb=al' => 'Lb/AL',
    'lb=alphabetic' => 'Lb/AL',
    'lb=ambiguous' => 'Lb/AI',
    'lb=b2' => 'Lb/B2',
    'lb=ba' => 'Lb/BA',
    'lb=bb' => 'Lb/BB',
    'lb=bk' => 'Lb/BK',
    'lb=breakafter' => 'Lb/BA',
    'lb=breakbefore' => 'Lb/BB',
    'lb=breakboth' => 'Lb/B2',
    'lb=breaksymbols' => 'Lb/SY',
    'lb=carriagereturn' => 'GCB/CR',
    'lb=cb' => 'Lb/CB',
    'lb=cl' => 'Lb/CL',
    'lb=closeparenthesis' => 'Lb/CP',
    'lb=closepunctuation' => 'Lb/CL',
    'lb=cm' => 'Lb/CM',
    'lb=combiningmark' => 'Lb/CM',
    'lb=complexcontext' => 'Lb/SA',
    'lb=contingentbreak' => 'Lb/CB',
    'lb=cp' => 'Lb/CP',
    'lb=cr' => 'GCB/CR',
    'lb=ex' => 'Lb/EX',
    'lb=exclamation' => 'Lb/EX',
    'lb=gl' => 'Lb/GL',
    'lb=glue' => 'Lb/GL',
    'lb=h2' => 'GCB/LV',
    'lb=h3' => 'GCB/LVT',
    'lb=hy' => 'Lb/HY',
    'lb=hyphen' => 'Lb/HY',
    'lb=id' => 'Lb/ID',
    'lb=ideographic' => 'Lb/ID',
    'lb=in' => 'Lb/IN',
    'lb=infixnumeric' => 'Lb/IS',
    'lb=inseparable' => 'Lb/IN',
    'lb=inseperable' => 'Lb/IN',
    'lb=is' => 'Lb/IS',
    'lb=jl' => 'GCB/L',
    'lb=jt' => 'GCB/T',
    'lb=jv' => 'GCB/V',
    'lb=lf' => 'GCB/LF',
    'lb=linefeed' => 'GCB/LF',
    'lb=mandatorybreak' => 'Lb/BK',
    'lb=nextline' => 'Lb/NL',
    'lb=nl' => 'Lb/NL',
    'lb=nonstarter' => 'Lb/NS',
    'lb=ns' => 'Lb/NS',
    'lb=nu' => 'Lb/NU',
    'lb=numeric' => 'Lb/NU',
    'lb=op' => 'Lb/OP',
    'lb=openpunctuation' => 'Lb/OP',
    'lb=po' => 'Lb/PO',
    'lb=postfixnumeric' => 'Lb/PO',
    'lb=pr' => 'Lb/PR',
    'lb=prefixnumeric' => 'Lb/PR',
    'lb=qu' => 'Lb/QU',
    'lb=quotation' => 'Lb/QU',
    'lb=sa' => 'Lb/SA',
    'lb=sg' => 'Lb/SG',
    'lb=sp' => 'Lb/SP',
    'lb=space' => 'Lb/SP',
    'lb=surrogate' => 'Lb/SG',
    'lb=sy' => 'Lb/SY',
    'lb=unknown' => 'Lb/XX',
    'lb=wj' => 'Lb/WJ',
    'lb=wordjoiner' => 'Lb/WJ',
    'lb=xx' => 'Lb/XX',
    'lb=zw' => 'Lb/ZW',
    'lb=zwspace' => 'Lb/ZW',
    'lc' => 'Gc/LC',
    'lepc' => 'Sc/Lepc',
    'lepcha' => 'Sc/Lepc',
    'letter' => 'Gc/L',
    'letterlikesymbols' => 'Blk/Letterli',
    'letternumber' => 'Gc/Nl',
    'limb' => 'Sc/Limb',
    'limbu' => 'Sc/Limb',
    'linb' => 'Sc/Linb',
    'linearb' => 'Sc/Linb',
    'linearbideograms' => 'Blk/LinearBI',
    'linearbsyllabary' => 'Blk/LinearBS',
    'lineseparator' => 'Gc/Zl',
    'lisu' => 'Blk/Lisu',
    'll' => 'Gc/Ll',
    'lm' => 'Gc/Lm',
    'lo' => 'Gc/Lo',
    'loe' => 'GCB/PP',
    'loe=f' => 'LOE/N',
    'loe=false' => 'LOE/N',
    'loe=n' => 'LOE/N',
    'loe=no' => 'LOE/N',
    'loe=t' => 'GCB/PP',
    'loe=true' => 'GCB/PP',
    'loe=y' => 'GCB/PP',
    'loe=yes' => 'GCB/PP',
    'logicalorderexception' => 'GCB/PP',
    'lower' => 'Lower/Y',
    'lower=f' => 'Lower/N',
    'lower=false' => 'Lower/N',
    'lower=n' => 'Lower/N',
    'lower=no' => 'Lower/N',
    'lower=t' => 'Lower/Y',
    'lower=true' => 'Lower/Y',
    'lower=y' => 'Lower/Y',
    'lower=yes' => 'Lower/Y',
    'lowercase' => 'Lower/Y',
    'lowercaseletter' => 'Gc/Ll',
    'lowsurrogates' => 'Blk/LowSurro',
    'lt' => 'Gc/Lt',
    'lu' => 'Gc/Lu',
    'lyci' => 'Sc/Lyci',
    'lycian' => 'Sc/Lyci',
    'lydi' => 'Sc/Lydi',
    'lydian' => 'Sc/Lydi',
    'm' => 'Gc/M',
    'mahjongtiles' => 'Blk/MahjongT',
    'malayalam' => 'Sc/Mlym',
    'mark' => 'Gc/M',
    'math' => 'Math/Y',
    'math=f' => 'Math/N',
    'math=false' => 'Math/N',
    'math=n' => 'Math/N',
    'math=no' => 'Math/N',
    'math=t' => 'Math/Y',
    'math=true' => 'Math/Y',
    'math=y' => 'Math/Y',
    'math=yes' => 'Math/Y',
    'mathematicalalphanumericsymbols' => 'Blk/Mathema2',
    'mathematicaloperators' => 'Blk/Mathemat',
    'mathsymbol' => 'Gc/Sm',
    'mc' => 'Gc/Mc',
    'me' => 'Gc/Me',
    'meeteimayek' => 'Sc/Mtei',
    'miscellaneousmathematicalsymbolsa' => 'Blk/Miscell4',
    'miscellaneousmathematicalsymbolsb' => 'Blk/Miscell5',
    'miscellaneoussymbols' => 'Blk/Miscella',
    'miscellaneoussymbolsandarrows' => 'Blk/Miscell3',
    'miscellaneoustechnical' => 'Blk/Miscell2',
    'mlym' => 'Sc/Mlym',
    'mn' => 'Gc/Mn',
    'modifierletter' => 'Gc/Lm',
    'modifiersymbol' => 'Gc/Sk',
    'modifiertoneletters' => 'Blk/Modifier',
    'mong' => 'Sc/Mong',
    'mongolian' => 'Sc/Mong',
    'mtei' => 'Sc/Mtei',
    'musicalsymbols' => 'Blk/MusicalS',
    'myanmar' => 'Sc/Mymr',
    'myanmarextendeda' => 'Blk/MyanmarE',
    'mymr' => 'Sc/Mymr',
    'n' => 'Gc/N',
    'nchar' => 'NChar/Y',
    'nchar=f' => 'NChar/N',
    'nchar=false' => 'NChar/N',
    'nchar=n' => 'NChar/N',
    'nchar=no' => 'NChar/N',
    'nchar=t' => 'NChar/Y',
    'nchar=true' => 'NChar/Y',
    'nchar=y' => 'NChar/Y',
    'nchar=yes' => 'NChar/Y',
    'nd' => 'Nt/De',
    'newtailue' => 'Sc/Talu',
    'nfcqc=m' => 'NFKCQC/M',
    'nfcqc=maybe' => 'NFKCQC/M',
    'nfcqc=n' => 'CompEx/Y',
    'nfcqc=no' => 'CompEx/Y',
    'nfcqc=y' => 'NFCQC/Y',
    'nfcqc=yes' => 'NFCQC/Y',
    'nfdqc=n' => 'NFDQC/N',
    'nfdqc=no' => 'NFDQC/N',
    'nfdqc=y' => 'NFDQC/Y',
    'nfdqc=yes' => 'NFDQC/Y',
    'nfkcqc=m' => 'NFKCQC/M',
    'nfkcqc=maybe' => 'NFKCQC/M',
    'nfkcqc=n' => 'NFKCQC/N',
    'nfkcqc=no' => 'NFKCQC/N',
    'nfkcqc=y' => 'NFKCQC/Y',
    'nfkcqc=yes' => 'NFKCQC/Y',
    'nfkdqc=n' => 'NFKDQC/N',
    'nfkdqc=no' => 'NFKDQC/N',
    'nfkdqc=y' => 'Dt/None',
    'nfkdqc=yes' => 'Dt/None',
    'nko' => 'Sc/Nko',
    'nkoo' => 'Sc/Nko',
    'nl' => 'Gc/Nl',
    'no' => 'Gc/No',
    'noblock' => 'Blk/NoBlock',
    'noncharactercodepoint' => 'NChar/Y',
    'nonspacingmark' => 'Gc/Mn',
    'nt=de' => 'Nt/De',
    'nt=decimal' => 'Nt/De',
    'nt=di' => 'Nt/Di',
    'nt=digit' => 'Nt/Di',
    'nt=none' => 'Nv/NaN',
    'nt=nu' => 'Nt/Nu',
    'nt=numeric' => 'Nt/Nu',
    'number' => 'Gc/N',
    'numberforms' => 'Blk/NumberFo',
    'nv=nan' => 'Nv/NaN',
    'oalpha' => 'OAlpha/Y',
    'oalpha=f' => 'OAlpha/N',
    'oalpha=false' => 'OAlpha/N',
    'oalpha=n' => 'OAlpha/N',
    'oalpha=no' => 'OAlpha/N',
    'oalpha=t' => 'OAlpha/Y',
    'oalpha=true' => 'OAlpha/Y',
    'oalpha=y' => 'OAlpha/Y',
    'oalpha=yes' => 'OAlpha/Y',
    'odi' => 'ODI/Y',
    'odi=f' => 'ODI/N',
    'odi=false' => 'ODI/N',
    'odi=n' => 'ODI/N',
    'odi=no' => 'ODI/N',
    'odi=t' => 'ODI/Y',
    'odi=true' => 'ODI/Y',
    'odi=y' => 'ODI/Y',
    'odi=yes' => 'ODI/Y',
    'ogam' => 'Sc/Ogam',
    'ogham' => 'Sc/Ogam',
    'ogrext' => 'OGrExt/Y',
    'ogrext=f' => 'OGrExt/N',
    'ogrext=false' => 'OGrExt/N',
    'ogrext=n' => 'OGrExt/N',
    'ogrext=no' => 'OGrExt/N',
    'ogrext=t' => 'OGrExt/Y',
    'ogrext=true' => 'OGrExt/Y',
    'ogrext=y' => 'OGrExt/Y',
    'ogrext=yes' => 'OGrExt/Y',
    'oidc' => 'OIDC/Y',
    'oidc=f' => 'OIDC/N',
    'oidc=false' => 'OIDC/N',
    'oidc=n' => 'OIDC/N',
    'oidc=no' => 'OIDC/N',
    'oidc=t' => 'OIDC/Y',
    'oidc=true' => 'OIDC/Y',
    'oidc=y' => 'OIDC/Y',
    'oidc=yes' => 'OIDC/Y',
    'oids' => 'OIDS/Y',
    'oids=f' => 'OIDS/N',
    'oids=false' => 'OIDS/N',
    'oids=n' => 'OIDS/N',
    'oids=no' => 'OIDS/N',
    'oids=t' => 'OIDS/Y',
    'oids=true' => 'OIDS/Y',
    'oids=y' => 'OIDS/Y',
    'oids=yes' => 'OIDS/Y',
    'olchiki' => 'Blk/OlChiki',
    'olck' => 'Blk/OlChiki',
    'olditalic' => 'Sc/Ital',
    'oldpersian' => 'Sc/Xpeo',
    'oldsoutharabian' => 'Blk/OldSouth',
    'oldturkic' => 'Sc/Orkh',
    'olower' => 'OLower/Y',
    'olower=f' => 'OLower/N',
    'olower=false' => 'OLower/N',
    'olower=n' => 'OLower/N',
    'olower=no' => 'OLower/N',
    'olower=t' => 'OLower/Y',
    'olower=true' => 'OLower/Y',
    'olower=y' => 'OLower/Y',
    'olower=yes' => 'OLower/Y',
    'omath' => 'OMath/Y',
    'omath=f' => 'OMath/N',
    'omath=false' => 'OMath/N',
    'omath=n' => 'OMath/N',
    'omath=no' => 'OMath/N',
    'omath=t' => 'OMath/Y',
    'omath=true' => 'OMath/Y',
    'omath=y' => 'OMath/Y',
    'omath=yes' => 'OMath/Y',
    'openpunctuation' => 'Gc/Ps',
    'opticalcharacterrecognition' => 'Blk/OpticalC',
    'oriya' => 'Sc/Orya',
    'orkh' => 'Sc/Orkh',
    'orya' => 'Sc/Orya',
    'osma' => 'Sc/Osma',
    'osmanya' => 'Sc/Osma',
    'other' => 'Gc/C',
    'otheralphabetic' => 'OAlpha/Y',
    'otherdefaultignorablecodepoint' => 'ODI/Y',
    'othergraphemeextend' => 'OGrExt/Y',
    'otheridcontinue' => 'OIDC/Y',
    'otheridstart' => 'OIDS/Y',
    'otherletter' => 'Gc/Lo',
    'otherlowercase' => 'OLower/Y',
    'othermath' => 'OMath/Y',
    'othernumber' => 'Gc/No',
    'otherpunctuation' => 'Gc/Po',
    'othersymbol' => 'Gc/So',
    'otheruppercase' => 'OUpper/Y',
    'oupper' => 'OUpper/Y',
    'oupper=f' => 'OUpper/N',
    'oupper=false' => 'OUpper/N',
    'oupper=n' => 'OUpper/N',
    'oupper=no' => 'OUpper/N',
    'oupper=t' => 'OUpper/Y',
    'oupper=true' => 'OUpper/Y',
    'oupper=y' => 'OUpper/Y',
    'oupper=yes' => 'OUpper/Y',
    'p' => 'Gc/P',
    'paragraphseparator' => 'Gc/Zp',
    'patsyn' => 'PatSyn/Y',
    'patsyn=f' => 'PatSyn/N',
    'patsyn=false' => 'PatSyn/N',
    'patsyn=n' => 'PatSyn/N',
    'patsyn=no' => 'PatSyn/N',
    'patsyn=t' => 'PatSyn/Y',
    'patsyn=true' => 'PatSyn/Y',
    'patsyn=y' => 'PatSyn/Y',
    'patsyn=yes' => 'PatSyn/Y',
    'patternsyntax' => 'PatSyn/Y',
    'patternwhitespace' => 'PatWS/Y',
    'patws' => 'PatWS/Y',
    'patws=f' => 'PatWS/N',
    'patws=false' => 'PatWS/N',
    'patws=n' => 'PatWS/N',
    'patws=no' => 'PatWS/N',
    'patws=t' => 'PatWS/Y',
    'patws=true' => 'PatWS/Y',
    'patws=y' => 'PatWS/Y',
    'patws=yes' => 'PatWS/Y',
    'pc' => 'WB/EX',
    'pd' => 'Gc/Pd',
    'pe' => 'Gc/Pe',
    'perlspace' => 'Perl/PerlSpac',
    'perlword' => 'Perl/PerlWord',
    'pf' => 'Gc/Pf',
    'phag' => 'Sc/Phag',
    'phagspa' => 'Sc/Phag',
    'phaistosdisc' => 'Blk/Phaistos',
    'phli' => 'Sc/Phli',
    'phnx' => 'Sc/Phnx',
    'phoenician' => 'Sc/Phnx',
    'phoneticextensions' => 'Blk/Phonetic',
    'phoneticextensionssupplement' => 'Blk/Phoneti2',
    'pi' => 'Gc/Pi',
    'po' => 'Gc/Po',
    'posixalnum' => 'Perl/PosixAln',
    'posixalpha' => 'Perl/PosixAlp',
    'posixblank' => 'Perl/PosixBla',
    'posixcntrl' => 'Perl/PosixCnt',
    'posixdigit' => 'Perl/PosixDig',
    'posixgraph' => 'Perl/PosixGra',
    'posixlower' => 'Perl/PosixLow',
    'posixprint' => 'Perl/PosixPri',
    'posixpunct' => 'Perl/PosixPun',
    'posixspace' => 'Perl/PosixSpa',
    'posixupper' => 'Perl/PosixUpp',
    'print' => 'Perl/Print',
    'privateuse' => 'Gc/Co',
    'privateusearea' => 'Blk/PrivateU',
    'prti' => 'Sc/Prti',
    'ps' => 'Gc/Ps',
    'punct' => 'Gc/P',
    'punctuation' => 'Gc/P',
    'qaac' => 'Sc/Copt',
    'qaai' => 'Sc/Zinh',
    'qmark' => 'QMark/Y',
    'qmark=f' => 'QMark/N',
    'qmark=false' => 'QMark/N',
    'qmark=n' => 'QMark/N',
    'qmark=no' => 'QMark/N',
    'qmark=t' => 'QMark/Y',
    'qmark=true' => 'QMark/Y',
    'qmark=y' => 'QMark/Y',
    'qmark=yes' => 'QMark/Y',
    'quotationmark' => 'QMark/Y',
    'radical' => 'Radical/Y',
    'radical=f' => 'Radical/N',
    'radical=false' => 'Radical/N',
    'radical=n' => 'Radical/N',
    'radical=no' => 'Radical/N',
    'radical=t' => 'Radical/Y',
    'radical=true' => 'Radical/Y',
    'radical=y' => 'Radical/Y',
    'radical=yes' => 'Radical/Y',
    'rejang' => 'Sc/Rjng',
    'rjng' => 'Sc/Rjng',
    'ruminumeralsymbols' => 'Blk/RumiNume',
    'runic' => 'Sc/Runr',
    'runr' => 'Sc/Runr',
    's' => 'Gc/S',
    'samaritan' => 'Sc/Samr',
    'samr' => 'Sc/Samr',
    'sarb' => 'Blk/OldSouth',
    'saur' => 'Sc/Saur',
    'saurashtra' => 'Sc/Saur',
    'sb=at' => 'SB/AT',
    'sb=aterm' => 'SB/AT',
    'sb=cl' => 'SB/CL',
    'sb=close' => 'SB/CL',
    'sb=cr' => 'GCB/CR',
    'sb=ex' => 'SB/EX',
    'sb=extend' => 'SB/EX',
    'sb=fo' => 'SB/FO',
    'sb=format' => 'SB/FO',
    'sb=le' => 'SB/LE',
    'sb=lf' => 'GCB/LF',
    'sb=lo' => 'SB/LO',
    'sb=lower' => 'SB/LO',
    'sb=nu' => 'Lb/NU',
    'sb=numeric' => 'Lb/NU',
    'sb=oletter' => 'SB/LE',
    'sb=other' => 'SB/XX',
    'sb=sc' => 'SB/SC',
    'sb=scontinue' => 'SB/SC',
    'sb=se' => 'SB/SE',
    'sb=sep' => 'SB/SE',
    'sb=sp' => 'SB/Sp',
    'sb=st' => 'SB/ST',
    'sb=sterm' => 'SB/ST',
    'sb=up' => 'SB/UP',
    'sb=upper' => 'SB/UP',
    'sb=xx' => 'SB/XX',
    'sc' => 'Gc/Sc',
    'sc=arab' => 'Sc/Arab',
    'sc=arabic' => 'Sc/Arab',
    'sc=armenian' => 'Sc/Armn',
    'sc=armi' => 'Sc/Armi',
    'sc=armn' => 'Sc/Armn',
    'sc=avestan' => 'Sc/Avst',
    'sc=avst' => 'Sc/Avst',
    'sc=bali' => 'Sc/Bali',
    'sc=balinese' => 'Sc/Bali',
    'sc=bamu' => 'Sc/Bamu',
    'sc=bamum' => 'Sc/Bamu',
    'sc=beng' => 'Sc/Beng',
    'sc=bengali' => 'Sc/Beng',
    'sc=bopo' => 'Sc/Bopo',
    'sc=bopomofo' => 'Sc/Bopo',
    'sc=brai' => 'Blk/BrailleP',
    'sc=braille' => 'Blk/BrailleP',
    'sc=bugi' => 'Sc/Bugi',
    'sc=buginese' => 'Sc/Bugi',
    'sc=buhd' => 'Sc/Buhd',
    'sc=buhid' => 'Sc/Buhd',
    'sc=canadianaboriginal' => 'Sc/Cans',
    'sc=cans' => 'Sc/Cans',
    'sc=cari' => 'Sc/Cari',
    'sc=carian' => 'Sc/Cari',
    'sc=cham' => 'Sc/Cham',
    'sc=cher' => 'Sc/Cher',
    'sc=cherokee' => 'Sc/Cher',
    'sc=common' => 'Sc/Zyyy',
    'sc=copt' => 'Sc/Copt',
    'sc=coptic' => 'Sc/Copt',
    'sc=cprt' => 'Sc/Cprt',
    'sc=cuneiform' => 'Sc/Xsux',
    'sc=cypriot' => 'Sc/Cprt',
    'sc=cyrillic' => 'Sc/Cyrl',
    'sc=cyrl' => 'Sc/Cyrl',
    'sc=deseret' => 'Blk/Deseret',
    'sc=deva' => 'Sc/Deva',
    'sc=devanagari' => 'Sc/Deva',
    'sc=dsrt' => 'Blk/Deseret',
    'sc=egyp' => 'Sc/Egyp',
    'sc=egyptianhieroglyphs' => 'Sc/Egyp',
    'sc=ethi' => 'Sc/Ethi',
    'sc=ethiopic' => 'Sc/Ethi',
    'sc=geor' => 'Sc/Geor',
    'sc=georgian' => 'Sc/Geor',
    'sc=glag' => 'Sc/Glag',
    'sc=glagolitic' => 'Sc/Glag',
    'sc=goth' => 'Sc/Goth',
    'sc=gothic' => 'Sc/Goth',
    'sc=greek' => 'Sc/Grek',
    'sc=grek' => 'Sc/Grek',
    'sc=gujarati' => 'Sc/Gujr',
    'sc=gujr' => 'Sc/Gujr',
    'sc=gurmukhi' => 'Sc/Guru',
    'sc=guru' => 'Sc/Guru',
    'sc=han' => 'Sc/Han',
    'sc=hang' => 'Sc/Hang',
    'sc=hangul' => 'Sc/Hang',
    'sc=hani' => 'Sc/Han',
    'sc=hano' => 'Sc/Hano',
    'sc=hanunoo' => 'Sc/Hano',
    'sc=hebr' => 'Sc/Hebr',
    'sc=hebrew' => 'Sc/Hebr',
    'sc=hira' => 'Sc/Hira',
    'sc=hiragana' => 'Sc/Hira',
    'sc=imperialaramaic' => 'Sc/Armi',
    'sc=inherited' => 'Sc/Zinh',
    'sc=inscriptionalpahlavi' => 'Sc/Phli',
    'sc=inscriptionalparthian' => 'Sc/Prti',
    'sc=ital' => 'Sc/Ital',
    'sc=java' => 'Sc/Java',
    'sc=javanese' => 'Sc/Java',
    'sc=kaithi' => 'Sc/Kthi',
    'sc=kali' => 'Blk/KayahLi',
    'sc=kana' => 'Sc/Kana',
    'sc=kannada' => 'Sc/Knda',
    'sc=katakana' => 'Sc/Kana',
    'sc=kayahli' => 'Blk/KayahLi',
    'sc=khar' => 'Sc/Khar',
    'sc=kharoshthi' => 'Sc/Khar',
    'sc=khmer' => 'Sc/Khmr',
    'sc=khmr' => 'Sc/Khmr',
    'sc=knda' => 'Sc/Knda',
    'sc=kthi' => 'Sc/Kthi',
    'sc=lana' => 'Sc/Lana',
    'sc=lao' => 'Sc/Lao',
    'sc=laoo' => 'Sc/Lao',
    'sc=latin' => 'Sc/Latn',
    'sc=latn' => 'Sc/Latn',
    'sc=lepc' => 'Sc/Lepc',
    'sc=lepcha' => 'Sc/Lepc',
    'sc=limb' => 'Sc/Limb',
    'sc=limbu' => 'Sc/Limb',
    'sc=linb' => 'Sc/Linb',
    'sc=linearb' => 'Sc/Linb',
    'sc=lisu' => 'Blk/Lisu',
    'sc=lyci' => 'Sc/Lyci',
    'sc=lycian' => 'Sc/Lyci',
    'sc=lydi' => 'Sc/Lydi',
    'sc=lydian' => 'Sc/Lydi',
    'sc=malayalam' => 'Sc/Mlym',
    'sc=meeteimayek' => 'Sc/Mtei',
    'sc=mlym' => 'Sc/Mlym',
    'sc=mong' => 'Sc/Mong',
    'sc=mongolian' => 'Sc/Mong',
    'sc=mtei' => 'Sc/Mtei',
    'sc=myanmar' => 'Sc/Mymr',
    'sc=mymr' => 'Sc/Mymr',
    'sc=newtailue' => 'Sc/Talu',
    'sc=nko' => 'Sc/Nko',
    'sc=nkoo' => 'Sc/Nko',
    'sc=ogam' => 'Sc/Ogam',
    'sc=ogham' => 'Sc/Ogam',
    'sc=olchiki' => 'Blk/OlChiki',
    'sc=olck' => 'Blk/OlChiki',
    'sc=olditalic' => 'Sc/Ital',
    'sc=oldpersian' => 'Sc/Xpeo',
    'sc=oldsoutharabian' => 'Blk/OldSouth',
    'sc=oldturkic' => 'Sc/Orkh',
    'sc=oriya' => 'Sc/Orya',
    'sc=orkh' => 'Sc/Orkh',
    'sc=orya' => 'Sc/Orya',
    'sc=osma' => 'Sc/Osma',
    'sc=osmanya' => 'Sc/Osma',
    'sc=phag' => 'Sc/Phag',
    'sc=phagspa' => 'Sc/Phag',
    'sc=phli' => 'Sc/Phli',
    'sc=phnx' => 'Sc/Phnx',
    'sc=phoenician' => 'Sc/Phnx',
    'sc=prti' => 'Sc/Prti',
    'sc=qaac' => 'Sc/Copt',
    'sc=qaai' => 'Sc/Zinh',
    'sc=rejang' => 'Sc/Rjng',
    'sc=rjng' => 'Sc/Rjng',
    'sc=runic' => 'Sc/Runr',
    'sc=runr' => 'Sc/Runr',
    'sc=samaritan' => 'Sc/Samr',
    'sc=samr' => 'Sc/Samr',
    'sc=sarb' => 'Blk/OldSouth',
    'sc=saur' => 'Sc/Saur',
    'sc=saurashtra' => 'Sc/Saur',
    'sc=shavian' => 'Blk/Shavian',
    'sc=shaw' => 'Blk/Shavian',
    'sc=sinh' => 'Sc/Sinh',
    'sc=sinhala' => 'Sc/Sinh',
    'sc=sund' => 'Sc/Sund',
    'sc=sundanese' => 'Sc/Sund',
    'sc=sylo' => 'Sc/Sylo',
    'sc=sylotinagri' => 'Sc/Sylo',
    'sc=syrc' => 'Sc/Syrc',
    'sc=syriac' => 'Sc/Syrc',
    'sc=tagalog' => 'Sc/Tglg',
    'sc=tagb' => 'Sc/Tagb',
    'sc=tagbanwa' => 'Sc/Tagb',
    'sc=taile' => 'Sc/Tale',
    'sc=taitham' => 'Sc/Lana',
    'sc=taiviet' => 'Sc/Tavt',
    'sc=tale' => 'Sc/Tale',
    'sc=talu' => 'Sc/Talu',
    'sc=tamil' => 'Sc/Taml',
    'sc=taml' => 'Sc/Taml',
    'sc=tavt' => 'Sc/Tavt',
    'sc=telu' => 'Sc/Telu',
    'sc=telugu' => 'Sc/Telu',
    'sc=tfng' => 'Sc/Tfng',
    'sc=tglg' => 'Sc/Tglg',
    'sc=thaa' => 'Sc/Thaa',
    'sc=thaana' => 'Sc/Thaa',
    'sc=thai' => 'Sc/Thai',
    'sc=tibetan' => 'Sc/Tibt',
    'sc=tibt' => 'Sc/Tibt',
    'sc=tifinagh' => 'Sc/Tfng',
    'sc=ugar' => 'Sc/Ugar',
    'sc=ugaritic' => 'Sc/Ugar',
    'sc=unknown' => 'Sc/Zzzz',
    'sc=vai' => 'Sc/Vai',
    'sc=vaii' => 'Sc/Vai',
    'sc=xpeo' => 'Sc/Xpeo',
    'sc=xsux' => 'Sc/Xsux',
    'sc=yi' => 'Sc/Yi',
    'sc=yiii' => 'Sc/Yi',
    'sc=zinh' => 'Sc/Zinh',
    'sc=zyyy' => 'Sc/Zyyy',
    'sc=zzzz' => 'Sc/Zzzz',
    'sd' => 'SD/Y',
    'sd=f' => 'SD/N',
    'sd=false' => 'SD/N',
    'sd=n' => 'SD/N',
    'sd=no' => 'SD/N',
    'sd=t' => 'SD/Y',
    'sd=true' => 'SD/Y',
    'sd=y' => 'SD/Y',
    'sd=yes' => 'SD/Y',
    'separator' => 'Gc/Z',
    'shavian' => 'Blk/Shavian',
    'shaw' => 'Blk/Shavian',
    'sinh' => 'Sc/Sinh',
    'sinhala' => 'Sc/Sinh',
    'sk' => 'Gc/Sk',
    'sm' => 'Gc/Sm',
    'smallformvariants' => 'Blk/SmallFor',
    'so' => 'Gc/So',
    'softdotted' => 'SD/Y',
    'space' => 'Space/Y',
    'spaceperl' => 'Perl/SpacePer',
    'spaceseparator' => 'Gc/Zs',
    'spacingmark' => 'Gc/Mc',
    'spacingmodifierletters' => 'Blk/SpacingM',
    'specials' => 'Blk/Specials',
    'sterm' => 'STerm/Y',
    'sterm=f' => 'STerm/N',
    'sterm=false' => 'STerm/N',
    'sterm=n' => 'STerm/N',
    'sterm=no' => 'STerm/N',
    'sterm=t' => 'STerm/Y',
    'sterm=true' => 'STerm/Y',
    'sterm=y' => 'STerm/Y',
    'sterm=yes' => 'STerm/Y',
    'sund' => 'Sc/Sund',
    'sundanese' => 'Sc/Sund',
    'superscriptsandsubscripts' => 'Blk/Superscr',
    'supplementalarrowsa' => 'Blk/Suppleme',
    'supplementalarrowsb' => 'Blk/Supplem2',
    'supplementalmathematicaloperators' => 'Blk/Supplem6',
    'supplementalpunctuation' => 'Blk/Supplem3',
    'supplementaryprivateuseareaa' => 'Blk/Supplem4',
    'supplementaryprivateuseareab' => 'Blk/Supplem5',
    'surrogate' => 'Gc/Cs',
    'sylo' => 'Sc/Sylo',
    'sylotinagri' => 'Sc/Sylo',
    'symbol' => 'Gc/S',
    'syrc' => 'Sc/Syrc',
    'syriac' => 'Sc/Syrc',
    'tagalog' => 'Sc/Tglg',
    'tagb' => 'Sc/Tagb',
    'tagbanwa' => 'Sc/Tagb',
    'tags' => 'Blk/Tags',
    'taile' => 'Sc/Tale',
    'taitham' => 'Sc/Lana',
    'taiviet' => 'Sc/Tavt',
    'taixuanjingsymbols' => 'Blk/TaiXuanJ',
    'tale' => 'Sc/Tale',
    'talu' => 'Sc/Talu',
    'tamil' => 'Sc/Taml',
    'taml' => 'Sc/Taml',
    'tavt' => 'Sc/Tavt',
    'telu' => 'Sc/Telu',
    'telugu' => 'Sc/Telu',
    'term' => 'Term/Y',
    'term=f' => 'Term/N',
    'term=false' => 'Term/N',
    'term=n' => 'Term/N',
    'term=no' => 'Term/N',
    'term=t' => 'Term/Y',
    'term=true' => 'Term/Y',
    'term=y' => 'Term/Y',
    'term=yes' => 'Term/Y',
    'terminalpunctuation' => 'Term/Y',
    'tfng' => 'Sc/Tfng',
    'tglg' => 'Sc/Tglg',
    'thaa' => 'Sc/Thaa',
    'thaana' => 'Sc/Thaa',
    'thai' => 'Sc/Thai',
    'tibetan' => 'Sc/Tibt',
    'tibt' => 'Sc/Tibt',
    'tifinagh' => 'Sc/Tfng',
    'title' => 'Gc/Lt',
    'titlecaseletter' => 'Gc/Lt',
    'ugar' => 'Sc/Ugar',
    'ugaritic' => 'Sc/Ugar',
    'uideo' => 'UIdeo/Y',
    'uideo=f' => 'UIdeo/N',
    'uideo=false' => 'UIdeo/N',
    'uideo=n' => 'UIdeo/N',
    'uideo=no' => 'UIdeo/N',
    'uideo=t' => 'UIdeo/Y',
    'uideo=true' => 'UIdeo/Y',
    'uideo=y' => 'UIdeo/Y',
    'uideo=yes' => 'UIdeo/Y',
    'unassigned' => 'Gc/Cn',
    'unifiedcanadianaboriginalsyllabics' => 'Blk/Canadian',
    'unifiedcanadianaboriginalsyllabicsextended' => 'Blk/UnifiedC',
    'unifiedideograph' => 'UIdeo/Y',
    'unknown' => 'Sc/Zzzz',
    'upper' => 'Upper/Y',
    'upper=f' => 'Upper/N',
    'upper=false' => 'Upper/N',
    'upper=n' => 'Upper/N',
    'upper=no' => 'Upper/N',
    'upper=t' => 'Upper/Y',
    'upper=true' => 'Upper/Y',
    'upper=y' => 'Upper/Y',
    'upper=yes' => 'Upper/Y',
    'uppercase' => 'Upper/Y',
    'uppercaseletter' => 'Gc/Lu',
    'vai' => 'Sc/Vai',
    'vaii' => 'Sc/Vai',
    'variationselector' => 'VS/Y',
    'variationselectors' => 'Blk/Variatio',
    'variationselectorssupplement' => 'Blk/Variati2',
    'vedicextensions' => 'Blk/VedicExt',
    'verticalforms' => 'Blk/Vertical',
    'vertspace' => 'Perl/VertSpac',
    'vs' => 'VS/Y',
    'vs=f' => 'VS/N',
    'vs=false' => 'VS/N',
    'vs=n' => 'VS/N',
    'vs=no' => 'VS/N',
    'vs=t' => 'VS/Y',
    'vs=true' => 'VS/Y',
    'vs=y' => 'VS/Y',
    'vs=yes' => 'VS/Y',
    'wb=aletter' => 'WB/LE',
    'wb=cr' => 'GCB/CR',
    'wb=ex' => 'WB/EX',
    'wb=extend' => 'SB/EX',
    'wb=extendnumlet' => 'WB/EX',
    'wb=fo' => 'WB/FO',
    'wb=format' => 'WB/FO',
    'wb=ka' => 'WB/KA',
    'wb=katakana' => 'WB/KA',
    'wb=le' => 'WB/LE',
    'wb=lf' => 'GCB/LF',
    'wb=mb' => 'WB/MB',
    'wb=midletter' => 'WB/ML',
    'wb=midnum' => 'WB/MN',
    'wb=midnumlet' => 'WB/MB',
    'wb=ml' => 'WB/ML',
    'wb=mn' => 'WB/MN',
    'wb=newline' => 'WB/NL',
    'wb=nl' => 'WB/NL',
    'wb=nu' => 'WB/NU',
    'wb=numeric' => 'WB/NU',
    'wb=other' => 'WB/XX',
    'wb=xx' => 'WB/XX',
    'whitespace' => 'Space/Y',
    'word' => 'Perl/Word',
    'wspace' => 'Space/Y',
    'wspace=f' => 'Space/N',
    'wspace=false' => 'Space/N',
    'wspace=n' => 'Space/N',
    'wspace=no' => 'Space/N',
    'wspace=t' => 'Space/Y',
    'wspace=true' => 'Space/Y',
    'wspace=y' => 'Space/Y',
    'wspace=yes' => 'Space/Y',
    'xdigit' => 'Hex/Y',
    'xidc' => 'XIDC/Y',
    'xidc=f' => 'XIDC/N',
    'xidc=false' => 'XIDC/N',
    'xidc=n' => 'XIDC/N',
    'xidc=no' => 'XIDC/N',
    'xidc=t' => 'XIDC/Y',
    'xidc=true' => 'XIDC/Y',
    'xidc=y' => 'XIDC/Y',
    'xidc=yes' => 'XIDC/Y',
    'xidcontinue' => 'XIDC/Y',
    'xids' => 'XIDS/Y',
    'xids=f' => 'XIDS/N',
    'xids=false' => 'XIDS/N',
    'xids=n' => 'XIDS/N',
    'xids=no' => 'XIDS/N',
    'xids=t' => 'XIDS/Y',
    'xids=true' => 'XIDS/Y',
    'xids=y' => 'XIDS/Y',
    'xids=yes' => 'XIDS/Y',
    'xidstart' => 'XIDS/Y',
    'xpeo' => 'Sc/Xpeo',
    'xsux' => 'Sc/Xsux',
    'yi' => 'Sc/Yi',
    'yiii' => 'Sc/Yi',
    'yijinghexagramsymbols' => 'Blk/YijingHe',
    'yiradicals' => 'Blk/YiRadica',
    'yisyllables' => 'Blk/YiSyllab',
    'z' => 'Gc/Z',
    'zinh' => 'Sc/Zinh',
    'zl' => 'Gc/Zl',
    'zp' => 'Gc/Zp',
    'zs' => 'Gc/Zs',
    'zyyy' => 'Sc/Zyyy',
    'zzzz' => 'Sc/Zzzz',
);

# Maps floating point to fractional form
%utf8::nv_floating_to_rational = (
    -0.5 => '-1/2',
    0.0625 => '1/16',
    0.1 => '1/10',
    0.111111111111111 => '1/9',
    0.125 => '1/8',
    0.142857142857143 => '1/7',
    0.166666666666667 => '1/6',
    0.1875 => '3/16',
    0.2 => '1/5',
    0.25 => '1/4',
    0.333333333333333 => '1/3',
    0.375 => '3/8',
    0.4 => '2/5',
    0.5 => '1/2',
    0.6 => '3/5',
    0.625 => '5/8',
    0.666666666666667 => '2/3',
    0.75 => '3/4',
    0.8 => '4/5',
    0.833333333333333 => '5/6',
    0.875 => '7/8',
    1.5 => '3/2',
    2.5 => '5/2',
    3.5 => '7/2',
    4.5 => '9/2',
    5.5 => '11/2',
    6.5 => '13/2',
    7.5 => '15/2',
    8.5 => '17/2',
);

# If a floating point number doesn't have enough digits in it to get this
# close to a fraction, it isn't considered to be that fraction even if all the
# digits it does have match.
$utf8::max_floating_slop = 0.001;

# Deprecated tables to generate a warning for.  The key is the file containing
# the table, so as to avoid duplication, as many property names can map to the
# file, but we only need one entry for all of them.
%utf8::why_deprecated = (
    'Lb/SG' => 'Deprecated by Unicode because surrogates should never appear in well-formed text, and therefore shouldn\'t be the basis for line breaking',
    'OAlpha/N' => 'Used by Unicode internally for generating the Alphabetic property (which should be used instead) and not intended to be used stand-alone',
    'OAlpha/Y' => 'Used by Unicode internally for generating the Alphabetic property (which should be used instead) and not intended to be used stand-alone',
    'ODI/N' => 'Used by Unicode internally for generating the Default_Ignorable_Code_Point property (which should be used instead) and not intended to be used stand-alone',
    'ODI/Y' => 'Used by Unicode internally for generating the Default_Ignorable_Code_Point property (which should be used instead) and not intended to be used stand-alone',
    'OGrExt/N' => 'Used by Unicode internally for generating the Grapheme_Extend property (which should be used instead) and not intended to be used stand-alone',
    'OGrExt/Y' => 'Used by Unicode internally for generating the Grapheme_Extend property (which should be used instead) and not intended to be used stand-alone',
    'OIDC/N' => 'Used by Unicode internally for generating the ID_Continue property (which should be used instead) and not intended to be used stand-alone',
    'OIDC/Y' => 'Used by Unicode internally for generating the ID_Continue property (which should be used instead) and not intended to be used stand-alone',
    'OIDS/N' => 'Used by Unicode internally for generating the ID_Start property (which should be used instead) and not intended to be used stand-alone',
    'OIDS/Y' => 'Used by Unicode internally for generating the ID_Start property (which should be used instead) and not intended to be used stand-alone',
    'OLower/N' => 'Used by Unicode internally for generating the Lowercase property (which should be used instead) and not intended to be used stand-alone',
    'OLower/Y' => 'Used by Unicode internally for generating the Lowercase property (which should be used instead) and not intended to be used stand-alone',
    'OMath/N' => 'Used by Unicode internally for generating the Math property (which should be used instead) and not intended to be used stand-alone',
    'OMath/Y' => 'Used by Unicode internally for generating the Math property (which should be used instead) and not intended to be used stand-alone',
    'OUpper/N' => 'Used by Unicode internally for generating the Uppercase property (which should be used instead) and not intended to be used stand-alone',
    'OUpper/Y' => 'Used by Unicode internally for generating the Uppercase property (which should be used instead) and not intended to be used stand-alone',
);

1;
